@@ -7,7 +7,6 @@
 #include <float.h>
 #include "lc_file.h"
 #include "camera.h"
-#include "tr.h"
 #include "lc_application.h"
 #include "lc_context.h"
 
@@ -68,10 +67,7 @@ void lcCamera::Initialize()
 	m_fovy = 30.0f;
 	m_zNear = 25.0f;
 	m_zFar = 50000.0f;
-
 	mState = 0;
-
-	m_pTR = nullptr;
 	memset(m_strName, 0, sizeof(m_strName));
 }
 
@@ -193,7 +189,7 @@ bool lcCamera::ParseLDrawLine(QTextStream& Stream)
 
 bool lcCamera::FileLoad(lcFile& file)
 {
-	lcuint8 version, ch;
+	quint8 version, ch;
 
 	version = file.ReadU8();
 
@@ -205,10 +201,10 @@ bool lcCamera::FileLoad(lcFile& file)
 		if (file.ReadU8() != 1)
 			return false;
 
-		lcuint16 time;
+		quint16 time;
 		float param[4];
-		lcuint8 type;
-		lcuint32 n;
+		quint8 type;
+		quint32 n;
 
 		file.ReadU32(&n, 1);
 		while (n--)
@@ -278,7 +274,7 @@ bool lcCamera::FileLoad(lcFile& file)
 
 		while (ch--)
 		{
-			lcuint8 step;
+			quint8 step;
 			double eye[3], target[3], up[3];
 			float f[3];
 
@@ -318,13 +314,13 @@ bool lcCamera::FileLoad(lcFile& file)
 	}
 	else
 	{
-		lcint32 n;
+		qint32 n;
 
 		if (version < 6)
 		{
-			lcuint16 time;
+			quint16 time;
 			float param[4];
-			lcuint8 type;
+			quint8 type;
 
 			n = file.ReadS32();
 			while (n--)
@@ -371,8 +367,8 @@ bool lcCamera::FileLoad(lcFile& file)
 
 	if ((version > 1) && (version < 4))
 	{
-		lcuint32 show;
-		lcint32 user;
+		quint32 show;
+		qint32 user;
 
 		file.ReadU32(&show, 1);
 //		if (version > 2)
@@ -414,7 +410,7 @@ void lcCamera::CompareBoundingBox(lcVector3& Min, lcVector3& Max)
 	}
 }
 
-void lcCamera::Move(lcStep Step, bool AddKey, const lcVector3& Distance)
+void lcCamera::MoveSelected(lcStep Step, bool AddKey, const lcVector3& Distance)
 {
 	if (IsSimple())
 		AddKey = false;
@@ -447,6 +443,22 @@ void lcCamera::Move(lcStep Step, bool AddKey, const lcVector3& Distance)
 	mUpVector.Normalize();
 }
 
+void lcCamera::MoveRelative(const lcVector3& Distance, lcStep Step, bool AddKey)
+{
+	if (IsSimple())
+		AddKey = false;
+
+	lcVector3 Relative = lcMul30(Distance, lcMatrix44Transpose(mWorldView)) * 5.0f;
+
+	mPosition += Relative;
+	ChangeKey(mPositionKeys, mPosition, Step, AddKey);
+
+	mTargetPosition += Relative;
+	ChangeKey(mTargetPositionKeys, mTargetPosition, Step, AddKey);
+
+	UpdatePosition(Step);
+}
+
 void lcCamera::UpdatePosition(lcStep Step)
 {
 	if (!IsSimple())
@@ -774,7 +786,7 @@ void lcCamera::ZoomExtents(float AspectRatio, const lcVector3& Center, const lcV
 		lcVector3 Position(mPosition + Center - mTargetPosition);
 		lcMatrix44 ProjectionMatrix = lcMatrix44Perspective(m_fovy, AspectRatio, m_zNear, m_zFar);
 
-		mPosition = lcZoomExtents(Position, mWorldView, ProjectionMatrix, Points, NumPoints);
+		std::tie(mPosition, std::ignore) = lcZoomExtents(Position, mWorldView, ProjectionMatrix, Points, NumPoints);
 		mTargetPosition = Center;
 	}
 
@@ -820,7 +832,7 @@ void lcCamera::ZoomRegion(float AspectRatio, const lcVector3& Position, const lc
 		lcMatrix44 WorldView = lcMatrix44LookAt(Position, TargetPosition, mUpVector);
 		lcMatrix44 ProjectionMatrix = lcMatrix44Perspective(m_fovy, AspectRatio, m_zNear, m_zFar);
 
-		mPosition = lcZoomExtents(Position, WorldView, ProjectionMatrix, Corners, 2);
+		std::tie(mPosition, std::ignore) = lcZoomExtents(Position, WorldView, ProjectionMatrix, Corners, 2);
 		mTargetPosition = TargetPosition;
 	}
 
@@ -946,18 +958,18 @@ void lcCamera::SetViewpoint(lcViewpoint Viewpoint)
 		lcVector3(    0.0f,     0.0f, -1250.0f), // LC_VIEWPOINT_BOTTOM
 		lcVector3( 1250.0f,     0.0f,     0.0f), // LC_VIEWPOINT_LEFT
 		lcVector3(-1250.0f,     0.0f,     0.0f), // LC_VIEWPOINT_RIGHT
-		lcVector3( -375.0f,  -375.0f,   187.5f)  // LC_VIEWPOINT_HOME
+		lcVector3(  375.0f,  -375.0f,   187.5f)  // LC_VIEWPOINT_HOME
 	};
 
 	lcVector3 Ups[] =
 	{
-		lcVector3( 0.0f, 0.0f, 1.0f),
-		lcVector3( 0.0f, 0.0f, 1.0f),
-		lcVector3( 0.0f, 1.0f, 0.0f),
-		lcVector3( 0.0f,-1.0f, 0.0f),
-		lcVector3( 0.0f, 0.0f, 1.0f),
-		lcVector3( 0.0f, 0.0f, 1.0f),
-		lcVector3(-0.2357f, -0.2357f, 0.94281f)
+		lcVector3(0.0f, 0.0f, 1.0f),
+		lcVector3(0.0f, 0.0f, 1.0f),
+		lcVector3(0.0f, 1.0f, 0.0f),
+		lcVector3(0.0f,-1.0f, 0.0f),
+		lcVector3(0.0f, 0.0f, 1.0f),
+		lcVector3(0.0f, 0.0f, 1.0f),
+		lcVector3(0.2357f, -0.2357f, 0.94281f)
 	};
 
 	mPosition = Positions[Viewpoint];
@@ -971,44 +983,23 @@ void lcCamera::SetViewpoint(lcViewpoint Viewpoint)
 	UpdatePosition(1);
 }
 
-void lcCamera::StartTiledRendering(int tw, int th, int iw, int ih, float AspectRatio)
+void lcCamera::SetAngles(float Latitude, float Longitude)
 {
-	m_pTR = new TiledRender();
-	m_pTR->TileSize(tw, th);
-	m_pTR->ImageSize(iw, ih);
+	mPosition = lcVector3(0, -1, 0);
+	mTargetPosition = lcVector3(0, 0, 0);
+	mUpVector = lcVector3(0, 0, 1);
 
-	if (IsOrtho())
-	{
-		float OrthoHeight = GetOrthoHeight() / 2.0f;
-		float OrthoWidth = OrthoHeight * AspectRatio;
+	lcMatrix33 LongitudeMatrix = lcMatrix33RotationZ(LC_DTOR * Longitude);
+	mPosition = lcMul(mPosition, LongitudeMatrix);
 
-		m_pTR->Ortho(-OrthoWidth, OrthoWidth, -OrthoHeight, OrthoHeight, m_zNear, m_zFar * 4);
-	}
-	else
-		m_pTR->Perspective(m_fovy, AspectRatio, m_zNear, m_zFar);
-}
+	lcVector3 SideVector = lcMul(lcVector3(-1, 0, 0), LongitudeMatrix);
+	lcMatrix33 LatitudeMatrix = lcMatrix33FromAxisAngle(SideVector, LC_DTOR * Latitude);
+	mPosition = lcMul(mPosition, LatitudeMatrix);
+	mUpVector = lcMul(mUpVector, LatitudeMatrix);
 
-void lcCamera::GetTileInfo(int* row, int* col, int* width, int* height)
-{
-	if (m_pTR != nullptr)
-	{
-		*row = m_pTR->mRows - m_pTR->mCurrentRow - 1;
-		*col = m_pTR->mCurrentColumn;
-		*width = m_pTR->mCurrentTileWidth;
-		*height = m_pTR->mCurrentTileHeight;
-	}
-}
+	ChangeKey(mPositionKeys, mPosition, 1, false);
+	ChangeKey(mTargetPositionKeys, mTargetPosition, 1, false);
+	ChangeKey(mUpVectorKeys, mUpVector, 1, false);
 
-bool lcCamera::EndTile()
-{
-	if (m_pTR != nullptr)
-	{
-		if (m_pTR->EndTile())
-			return true;
-
-		delete m_pTR;
-		m_pTR = nullptr;
-	}
-
-	return false;
+	UpdatePosition(1);
 }
