@@ -7,35 +7,35 @@ lcCommand gCommands[LC_NUM_COMMANDS] =
 	{
 		QT_TRANSLATE_NOOP("Action", "File.New"),
 		QT_TRANSLATE_NOOP("Menu", "&New"),
-		QT_TRANSLATE_NOOP("Status", "Create a new project"),
+		QT_TRANSLATE_NOOP("Status", "Create a new model"),
 		QT_TRANSLATE_NOOP("Shortcut", "Ctrl+N")
 	},
 	// LC_FILE_OPEN
 	{
 		QT_TRANSLATE_NOOP("Action", "File.Open"),
 		QT_TRANSLATE_NOOP("Menu", "&Open..."),
-		QT_TRANSLATE_NOOP("Status", "Open an existing project"),
+		QT_TRANSLATE_NOOP("Status", "Open an existing model"),
 		QT_TRANSLATE_NOOP("Shortcut", "Ctrl+O")
 	},
 	// LC_FILE_MERGE
 	{
 		QT_TRANSLATE_NOOP("Action", "File.Merge"),
 		QT_TRANSLATE_NOOP("Menu", "&Merge..."),
-		QT_TRANSLATE_NOOP("Status", "Merge the contents of another project with the current one"),
+		QT_TRANSLATE_NOOP("Status", "Merge the contents of another file with the current one"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_FILE_SAVE
 	{
 		QT_TRANSLATE_NOOP("Action", "File.Save"),
 		QT_TRANSLATE_NOOP("Menu", "&Save"),
-		QT_TRANSLATE_NOOP("Status", "Save the active project"),
+		QT_TRANSLATE_NOOP("Status", "Save the current model"),
 		QT_TRANSLATE_NOOP("Shortcut", "Ctrl+S")
 	},
 	// LC_FILE_SAVEAS
 	{
 		QT_TRANSLATE_NOOP("Action", "File.SaveAs"),
 		QT_TRANSLATE_NOOP("Menu", "Save &As..."),
-		QT_TRANSLATE_NOOP("Status", "Save the active project with a new name"),
+		QT_TRANSLATE_NOOP("Status", "Save the current model with a new name"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_FILE_SAVE_IMAGE
@@ -52,18 +52,32 @@ lcCommand gCommands[LC_NUM_COMMANDS] =
 		QT_TRANSLATE_NOOP("Status", "Import a file in LEGO Digital Designer LXF format"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
+	// LC_FILE_IMPORT_INVENTORY
+	{
+		QT_TRANSLATE_NOOP("Action", "File.Import.Inventory"),
+		QT_TRANSLATE_NOOP("Menu", "Set &Inventory..."),
+		QT_TRANSLATE_NOOP("Status", "Import all parts from an official set"),
+		QT_TRANSLATE_NOOP("Shortcut", "")
+	},
 	// LC_FILE_EXPORT_3DS
 	{
 		QT_TRANSLATE_NOOP("Action", "File.Export.3DS"),
 		QT_TRANSLATE_NOOP("Menu", "3D &Studio..."),
-		QT_TRANSLATE_NOOP("Status", "Export the project in 3D Studio 3DS format"),
+		QT_TRANSLATE_NOOP("Status", "Export the current model in 3D Studio 3DS format"),
+		QT_TRANSLATE_NOOP("Shortcut", "")
+	},
+	// LC_FILE_EXPORT_COLLADA
+	{
+		QT_TRANSLATE_NOOP("Action", "File.Export.COLLADA"),
+		QT_TRANSLATE_NOOP("Menu", "&COLLADA..."),
+		QT_TRANSLATE_NOOP("Status", "Export the current model in COLLADA DAE format"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_FILE_EXPORT_HTML
 	{
 		QT_TRANSLATE_NOOP("Action", "File.Export.HTML"),
 		QT_TRANSLATE_NOOP("Menu", "&HTML..."),
-		QT_TRANSLATE_NOOP("Status", "Create an HTML page for this project"),
+		QT_TRANSLATE_NOOP("Status", "Create an HTML page for the current model"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_FILE_EXPORT_BRICKLINK
@@ -84,28 +98,35 @@ lcCommand gCommands[LC_NUM_COMMANDS] =
 	{
 		QT_TRANSLATE_NOOP("Action", "File.Export.POVRay"),
 		QT_TRANSLATE_NOOP("Menu", "&POV-Ray..."),
-		QT_TRANSLATE_NOOP("Status", "Export the project in POV-Ray format"),
+		QT_TRANSLATE_NOOP("Status", "Export the current model in POV-Ray format"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_FILE_EXPORT_WAVEFRONT
 	{
 		QT_TRANSLATE_NOOP("Action", "File.Export.Wavefront"),
 		QT_TRANSLATE_NOOP("Menu", "&Wavefront..."),
-		QT_TRANSLATE_NOOP("Status", "Export the project in Wavefront OBJ format"),
+		QT_TRANSLATE_NOOP("Status", "Export the current model in Wavefront OBJ format"),
+		QT_TRANSLATE_NOOP("Shortcut", "")
+	},
+	// LC_FILE_RENDER
+	{
+		QT_TRANSLATE_NOOP("Action", "File.Render"),
+		QT_TRANSLATE_NOOP("Menu", "&Render..."),
+		QT_TRANSLATE_NOOP("Status", "Render the current model using POV-Ray"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_FILE_PRINT
 	{
 		QT_TRANSLATE_NOOP("Action", "File.Print"),
 		QT_TRANSLATE_NOOP("Menu", "&Print..."),
-		QT_TRANSLATE_NOOP("Status", "Print the active project"),
+		QT_TRANSLATE_NOOP("Status", "Print the current model"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_FILE_PRINT_PREVIEW
 	{
 		QT_TRANSLATE_NOOP("Action", "File.PrintPreview"),
 		QT_TRANSLATE_NOOP("Menu", "Print Pre&view..."),
-		QT_TRANSLATE_NOOP("Status", "Display how the project would look if printed"),
+		QT_TRANSLATE_NOOP("Status", "Display how the model would look if printed"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_FILE_PRINT_BOM
@@ -119,35 +140,35 @@ lcCommand gCommands[LC_NUM_COMMANDS] =
 	{
 		QT_TRANSLATE_NOOP("Action", "File.Recent1"),
 		QT_TRANSLATE_NOOP("Menu", "&Recent1"),
-		QT_TRANSLATE_NOOP("Status", "Open this document"),
+		QT_TRANSLATE_NOOP("Status", "Open this model"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_FILE_RECENT2
 	{
 		QT_TRANSLATE_NOOP("Action", "File.Recent2"),
 		QT_TRANSLATE_NOOP("Menu", "&Recent2"),
-		QT_TRANSLATE_NOOP("Status", "Open this document"),
+		QT_TRANSLATE_NOOP("Status", "Open this model"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_FILE_RECENT3
 	{
 		QT_TRANSLATE_NOOP("Action", "File.Recent3"),
 		QT_TRANSLATE_NOOP("Menu", "&Recent3"),
-		QT_TRANSLATE_NOOP("Status", "Open this document"),
+		QT_TRANSLATE_NOOP("Status", "Open this model"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_FILE_RECENT4
 	{
 		QT_TRANSLATE_NOOP("Action", "File.Recent4"),
 		QT_TRANSLATE_NOOP("Menu", "&Recent4"),
-		QT_TRANSLATE_NOOP("Status", "Open this document"),
+		QT_TRANSLATE_NOOP("Status", "Open this model"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_FILE_EXIT
 	{
 		QT_TRANSLATE_NOOP("Action", "File.Exit"),
 		QT_TRANSLATE_NOOP("Menu", "E&xit"),
-		QT_TRANSLATE_NOOP("Status", "Quit the application; prompts to save project"),
+		QT_TRANSLATE_NOOP("Status", "Quit the application; prompts to save model"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_EDIT_UNDO
@@ -210,7 +231,7 @@ lcCommand gCommands[LC_NUM_COMMANDS] =
 	{
 		QT_TRANSLATE_NOOP("Action", "Edit.SelectAll"),
 		QT_TRANSLATE_NOOP("Menu", "Select &All"),
-		QT_TRANSLATE_NOOP("Status", "Select all pieces in the project"),
+		QT_TRANSLATE_NOOP("Status", "Select all pieces in the model"),
 		QT_TRANSLATE_NOOP("Shortcut", "Ctrl+A")
 	},
 	// LC_EDIT_SELECT_NONE
@@ -241,32 +262,32 @@ lcCommand gCommands[LC_NUM_COMMANDS] =
 		QT_TRANSLATE_NOOP("Status", "Select pieces by color"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
-	// LC_EDIT_LOCK_X
+	// LC_EDIT_SELECT_SINGLE
 	{
-		QT_TRANSLATE_NOOP("Action", "Edit.Lock.LockX"),
-		QT_TRANSLATE_NOOP("Menu", "Lock X"),
-		QT_TRANSLATE_NOOP("Status", "Prevents movement and rotation along the X axis"),
+		QT_TRANSLATE_NOOP("Action", "Edit.SelectSingle"),
+		QT_TRANSLATE_NOOP("Menu", "Single Selection"),
+		QT_TRANSLATE_NOOP("Status", "Select one piece at a time"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
-	// LC_EDIT_LOCK_Y
+	// LC_EDIT_SELECT_PIECE
 	{
-		QT_TRANSLATE_NOOP("Action", "Edit.Lock.LockY"),
-		QT_TRANSLATE_NOOP("Menu", "Lock Y"),
-		QT_TRANSLATE_NOOP("Status", "Prevents movement and rotation along the Y axis"),
+		QT_TRANSLATE_NOOP("Action", "Edit.SelectPiece"),
+		QT_TRANSLATE_NOOP("Menu", "Piece Selection"),
+		QT_TRANSLATE_NOOP("Status", "Select all pieces of the same type"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
-	// LC_EDIT_LOCK_Z
+	// LC_EDIT_SELECT_COLOR
 	{
-		QT_TRANSLATE_NOOP("Action", "Edit.Lock.LockZ"),
-		QT_TRANSLATE_NOOP("Menu", "Lock Z"),
-		QT_TRANSLATE_NOOP("Status", "Prevents movement and rotation along the Z axis"),
+		QT_TRANSLATE_NOOP("Action", "Edit.SelectColor"),
+		QT_TRANSLATE_NOOP("Menu", "Color Selection"),
+		QT_TRANSLATE_NOOP("Status", "Select all pieces of the same color"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
-	// LC_EDIT_LOCK_NONE
+	// LC_EDIT_SELECT_PIECE_COLOR
 	{
-		QT_TRANSLATE_NOOP("Action", "Edit.Lock.None"),
-		QT_TRANSLATE_NOOP("Menu", "Unlock All"),
-		QT_TRANSLATE_NOOP("Status", "Allows movement and rotation in all directions"),
+		QT_TRANSLATE_NOOP("Action", "Edit.SelectPieceColor"),
+		QT_TRANSLATE_NOOP("Menu", "Piece and Color Selection"),
+		QT_TRANSLATE_NOOP("Status", "Select all pieces of the same type and color"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_EDIT_TRANSFORM_RELATIVE
@@ -454,15 +475,15 @@ lcCommand gCommands[LC_NUM_COMMANDS] =
 	// LC_EDIT_SNAP_ANGLE3
 	{
 		QT_TRANSLATE_NOOP("Action", "Edit.SnapAngle.Angle3"),
-		QT_TRANSLATE_NOOP("Menu", "10 Degrees"),
-		QT_TRANSLATE_NOOP("Status", "Snap rotations to 10 degrees"),
+		QT_TRANSLATE_NOOP("Menu", "15 Degrees"),
+		QT_TRANSLATE_NOOP("Status", "Snap rotations to 15 degrees"),
 		QT_TRANSLATE_NOOP("Shortcut", "Shift+3")
 	},
 	// LC_EDIT_SNAP_ANGLE4
 	{
 		QT_TRANSLATE_NOOP("Action", "Edit.SnapAngle.Angle4"),
-		QT_TRANSLATE_NOOP("Menu", "15 Degrees"),
-		QT_TRANSLATE_NOOP("Status", "Snap rotations to 15 degrees"),
+		QT_TRANSLATE_NOOP("Menu", "22.5 Degrees"),
+		QT_TRANSLATE_NOOP("Status", "Snap rotations to 22.5 degrees"),
 		QT_TRANSLATE_NOOP("Shortcut", "Shift+4")
 	},
 	// LC_EDIT_SNAP_ANGLE5
@@ -568,63 +589,63 @@ lcCommand gCommands[LC_NUM_COMMANDS] =
 		QT_TRANSLATE_NOOP("Action", "Edit.Tool.Select"),
 		QT_TRANSLATE_NOOP("Menu", "Select"),
 		QT_TRANSLATE_NOOP("Status", "Select objects (hold the CTRL key down or drag the mouse to select multiple objects)"),
-		QT_TRANSLATE_NOOP("Shortcut", "Shift+S")
+		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_EDIT_ACTION_MOVE
 	{
 		QT_TRANSLATE_NOOP("Action", "Edit.Tool.Move"),
 		QT_TRANSLATE_NOOP("Menu", "Move"),
 		QT_TRANSLATE_NOOP("Status", "Move selected objects"),
-		QT_TRANSLATE_NOOP("Shortcut", "Shift+M")
+		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_EDIT_ACTION_ROTATE
 	{
 		QT_TRANSLATE_NOOP("Action", "Edit.Tool.Rotate"),
 		QT_TRANSLATE_NOOP("Menu", "Rotate"),
 		QT_TRANSLATE_NOOP("Status", "Rotate selected pieces"),
-		QT_TRANSLATE_NOOP("Shortcut", "Shift+R")
+		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_EDIT_ACTION_DELETE
 	{
 		QT_TRANSLATE_NOOP("Action", "Edit.Tool.Delete"),
 		QT_TRANSLATE_NOOP("Menu", "Delete"),
 		QT_TRANSLATE_NOOP("Status", "Delete objects"),
-		QT_TRANSLATE_NOOP("Shortcut", "Shift+D")
+		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_EDIT_ACTION_PAINT
 	{
 		QT_TRANSLATE_NOOP("Action", "Edit.Tool.Paint"),
 		QT_TRANSLATE_NOOP("Menu", "Paint"),
 		QT_TRANSLATE_NOOP("Status", "Change piece color"),
-		QT_TRANSLATE_NOOP("Shortcut", "Shift+N")
+		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_EDIT_ACTION_ZOOM
 	{
 		QT_TRANSLATE_NOOP("Action", "Edit.Tool.Zoom"),
 		QT_TRANSLATE_NOOP("Menu", "Zoom"),
 		QT_TRANSLATE_NOOP("Status", "Zoom in or out"),
-		QT_TRANSLATE_NOOP("Shortcut", "Shift+Z")
+		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_EDIT_ACTION_PAN
 	{
 		QT_TRANSLATE_NOOP("Action", "Edit.Tool.Pan"),
 		QT_TRANSLATE_NOOP("Menu", "Pan"),
 		QT_TRANSLATE_NOOP("Status", "Pan the current view"),
-		QT_TRANSLATE_NOOP("Shortcut", "Shift+P")
+		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_EDIT_ACTION_ROTATE_VIEW
 	{
 		QT_TRANSLATE_NOOP("Action", "Edit.Tool.RotateView"),
 		QT_TRANSLATE_NOOP("Menu", "Rotate View"),
 		QT_TRANSLATE_NOOP("Status", "Rotate the current view"),
-		QT_TRANSLATE_NOOP("Shortcut", "Shift+T")
+		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_EDIT_ACTION_ROLL
 	{
 		QT_TRANSLATE_NOOP("Action", "Edit.Tool.Roll"),
 		QT_TRANSLATE_NOOP("Menu", "Roll"),
 		QT_TRANSLATE_NOOP("Status", "Roll the current view"),
-		QT_TRANSLATE_NOOP("Shortcut", "Shift+L")
+		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_EDIT_ACTION_ZOOM_REGION
 	{
@@ -675,6 +696,48 @@ lcCommand gCommands[LC_NUM_COMMANDS] =
 		QT_TRANSLATE_NOOP("Status", "Rotate view so selected pieces are at center"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
+	// LC_VIEW_MOVE_FORWARD
+	{
+		QT_TRANSLATE_NOOP("Action", "View.MoveForward"),
+		QT_TRANSLATE_NOOP("Menu", "Move Forward"),
+		QT_TRANSLATE_NOOP("Status", "Move the current view forward"),
+		QT_TRANSLATE_NOOP("Shortcut", "")
+	},
+	// LC_VIEW_MOVE_BACKWARD
+	{
+		QT_TRANSLATE_NOOP("Action", "View.MoveBackward"),
+		QT_TRANSLATE_NOOP("Menu", "Move Backward"),
+		QT_TRANSLATE_NOOP("Status", "Move the current view backward"),
+		QT_TRANSLATE_NOOP("Shortcut", "")
+	},
+	// LC_VIEW_MOVE_LEFT
+	{
+		QT_TRANSLATE_NOOP("Action", "View.MoveLeft"),
+		QT_TRANSLATE_NOOP("Menu", "Move Left"),
+		QT_TRANSLATE_NOOP("Status", "Move the current view to the left"),
+		QT_TRANSLATE_NOOP("Shortcut", "")
+	},
+	// LC_VIEW_MOVE_RIGHT
+	{
+		QT_TRANSLATE_NOOP("Action", "View.MoveRight"),
+		QT_TRANSLATE_NOOP("Menu", "Move Right"),
+		QT_TRANSLATE_NOOP("Status", "Move the current view to the right"),
+		QT_TRANSLATE_NOOP("Shortcut", "")
+	},
+	// LC_VIEW_MOVE_UP
+	{
+		QT_TRANSLATE_NOOP("Action", "View.MoveUp"),
+		QT_TRANSLATE_NOOP("Menu", "Move Up"),
+		QT_TRANSLATE_NOOP("Status", "Move the current view up"),
+		QT_TRANSLATE_NOOP("Shortcut", "")
+	},
+	// LC_VIEW_MOVE_DOWN
+	{
+		QT_TRANSLATE_NOOP("Action", "View.MoveDown"),
+		QT_TRANSLATE_NOOP("Menu", "Move Down"),
+		QT_TRANSLATE_NOOP("Status", "Move the current view down"),
+		QT_TRANSLATE_NOOP("Shortcut", "")
+	},
 	// LC_VIEW_VIEWPOINT_FRONT
 	{
 		QT_TRANSLATE_NOOP("Action", "View.Viewpoint.Front"),
@@ -934,6 +997,27 @@ lcCommand gCommands[LC_NUM_COMMANDS] =
 		QT_TRANSLATE_NOOP("Status", "Toggle fullscreen mode"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
+	// LC_VIEW_SHADE_WIREFRAME
+	{
+		QT_TRANSLATE_NOOP("Action", "View.Shade.Wireframe"),
+		QT_TRANSLATE_NOOP("Menu", "&Wireframe"),
+		QT_TRANSLATE_NOOP("Status", "Display the scene as wireframe"),
+		QT_TRANSLATE_NOOP("Shortcut", "")
+	},
+	// LC_VIEW_SHADE_FLAT
+	{
+		QT_TRANSLATE_NOOP("Action", "View.Shade.Flat"),
+		QT_TRANSLATE_NOOP("Menu", "&Flat Shading"),
+		QT_TRANSLATE_NOOP("Status", "Display the scene without any shading or lights"),
+		QT_TRANSLATE_NOOP("Shortcut", "")
+	},
+	// LC_VIEW_SHADE_DEFAULT_LIGHTS
+	{
+		QT_TRANSLATE_NOOP("Action", "View.Shade.DefaultLights"),
+		QT_TRANSLATE_NOOP("Menu", "&Default Lights"),
+		QT_TRANSLATE_NOOP("Status", "Display the scene with the default lights"),
+		QT_TRANSLATE_NOOP("Shortcut", "")
+	},
 	// LC_VIEW_PROJECTION_PERSPECTIVE
 	{
 		QT_TRANSLATE_NOOP("Action", "View.Projection.Perspective"),
@@ -1189,197 +1273,197 @@ lcCommand gCommands[LC_NUM_COMMANDS] =
 	// LC_MODEL_NEW
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.New"),
-		QT_TRANSLATE_NOOP("Menu", "New Model..."),
-		QT_TRANSLATE_NOOP("Status", "Add a new model to the project"),
+		QT_TRANSLATE_NOOP("Menu", "New Submodel..."),
+		QT_TRANSLATE_NOOP("Status", "Create a new submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_PROPERTIES
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Properties"),
 		QT_TRANSLATE_NOOP("Menu", "Prope&rties..."),
-		QT_TRANSLATE_NOOP("Status", "Display the properties of the current model"),
+		QT_TRANSLATE_NOOP("Status", "Display the properties of the current submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_EDIT_FOCUS
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.SwitchToFocus"),
-		QT_TRANSLATE_NOOP("Menu", "Switch to Model"),
-		QT_TRANSLATE_NOOP("Status", "Switch to the model corresponding to the piece with focus"),
+		QT_TRANSLATE_NOOP("Menu", "Switch to Submodel"),
+		QT_TRANSLATE_NOOP("Status", "Switch to the submodel corresponding to the piece with focus"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_LIST
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.List"),
-		QT_TRANSLATE_NOOP("Menu", "Models..."),
-		QT_TRANSLATE_NOOP("Status", "Show a list of all models in this project"),
+		QT_TRANSLATE_NOOP("Menu", "Submodels..."),
+		QT_TRANSLATE_NOOP("Status", "Show a list of all submodels"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_01
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model01"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_02
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model02"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_03
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model03"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_04
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model04"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_05
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model05"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_06
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model06"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_07
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model07"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_08
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model08"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_09
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model09"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_10
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model10"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_11
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model11"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_12
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model12"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_13
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model13"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_14
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model14"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_15
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model15"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_16
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model16"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_17
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model17"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_18
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model18"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_19
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model19"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_20
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model20"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_21
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model21"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_22
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model22"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_23
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model23"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_MODEL_24
 	{
 		QT_TRANSLATE_NOOP("Action", "Model.Model24"),
 		QT_TRANSLATE_NOOP("Menu", ""),
-		QT_TRANSLATE_NOOP("Status", "Switch to this model"),
+		QT_TRANSLATE_NOOP("Status", "Switch to this submodel"),
 		QT_TRANSLATE_NOOP("Shortcut", "")
 	},
 	// LC_HELP_HOMEPAGE
