@@ -1,5 +1,4 @@
-#ifndef _LC_COMMANDS_H_
-#define _LC_COMMANDS_H_
+#pragma once
 
 enum lcCommandId
 {
@@ -10,12 +9,15 @@ enum lcCommandId
 	LC_FILE_SAVEAS,
 	LC_FILE_SAVE_IMAGE,
 	LC_FILE_IMPORT_LDD,
+	LC_FILE_IMPORT_INVENTORY,
 	LC_FILE_EXPORT_3DS,
+	LC_FILE_EXPORT_COLLADA,
 	LC_FILE_EXPORT_HTML,
 	LC_FILE_EXPORT_BRICKLINK,
 	LC_FILE_EXPORT_CSV,
 	LC_FILE_EXPORT_POVRAY,
 	LC_FILE_EXPORT_WAVEFRONT,
+	LC_FILE_RENDER,
 	LC_FILE_PRINT,
 	LC_FILE_PRINT_PREVIEW,
 	LC_FILE_PRINT_BOM,
@@ -39,10 +41,12 @@ enum lcCommandId
 	LC_EDIT_SELECT_INVERT,
 	LC_EDIT_SELECT_BY_NAME,
 	LC_EDIT_SELECT_BY_COLOR,
-	LC_EDIT_LOCK_X,
-	LC_EDIT_LOCK_Y,
-	LC_EDIT_LOCK_Z,
-	LC_EDIT_LOCK_NONE,
+	LC_EDIT_SELECTION_MODE_FIRST,
+	LC_EDIT_SELECTION_SINGLE = LC_EDIT_SELECTION_MODE_FIRST,
+	LC_EDIT_SELECTION_PIECE,
+	LC_EDIT_SELECTION_COLOR,
+	LC_EDIT_SELECTION_PIECE_COLOR,
+	LC_EDIT_SELECTION_MODE_LAST = LC_EDIT_SELECTION_PIECE_COLOR,
 	LC_EDIT_TRANSFORM_RELATIVE,
 	LC_EDIT_SNAP_MOVE_TOGGLE,
 	LC_EDIT_SNAP_MOVE_XY0,
@@ -103,6 +107,12 @@ enum lcCommandId
 	LC_VIEW_ZOOM_OUT,
 	LC_VIEW_ZOOM_EXTENTS,
 	LC_VIEW_LOOK_AT,
+	LC_VIEW_MOVE_FORWARD,
+	LC_VIEW_MOVE_BACKWARD,
+	LC_VIEW_MOVE_LEFT,
+	LC_VIEW_MOVE_RIGHT,
+	LC_VIEW_MOVE_UP,
+	LC_VIEW_MOVE_DOWN,
 	LC_VIEW_VIEWPOINT_FRONT,
 	LC_VIEW_VIEWPOINT_BACK,
 	LC_VIEW_VIEWPOINT_TOP,
@@ -142,6 +152,11 @@ enum lcCommandId
 	LC_VIEW_REMOVE_VIEW,
 	LC_VIEW_RESET_VIEWS,
 	LC_VIEW_FULLSCREEN,
+	LC_VIEW_SHADING_FIRST,
+	LC_VIEW_SHADING_WIREFRAME = LC_VIEW_SHADING_FIRST,
+	LC_VIEW_SHADING_FLAT,
+	LC_VIEW_SHADING_DEFAULT_LIGHTS,
+	LC_VIEW_SHADING_LAST = LC_VIEW_SHADING_DEFAULT_LIGHTS,
 	LC_VIEW_PROJECTION_FIRST,
 	LC_VIEW_PROJECTION_PERSPECTIVE = LC_VIEW_PROJECTION_FIRST,
 	LC_VIEW_PROJECTION_ORTHO,
@@ -252,4 +267,3 @@ enum lcTool
 
 extern const char* gToolNames[LC_NUM_TOOLS];
 
-#endif // _LC_COMMANDS_H_
