@@ -5,6 +5,7 @@ bool gSupportsShaderObjects;
 bool gSupportsVertexBufferObject;
 bool gSupportsFramebufferObjectARB;
 bool gSupportsFramebufferObjectEXT;
+bool gSupportsTexImage2DMultisample;
 bool gSupportsAnisotropic;
 GLfloat gMaxAnisotropy;
 
@@ -114,6 +115,8 @@ PFNGLUNIFORMMATRIX4FVPROC lcUniformMatrix4fv;
 PFNGLVALIDATEPROGRAMPROC lcValidateProgram;
 PFNGLVERTEXATTRIBPOINTERPROC lcVertexAttribPointer;
 
+PFNGLTEXIMAGE2DMULTISAMPLEPROC lcTexImage2DMultisample;
+
 #endif
 
 static bool lcIsGLExtensionSupported(const GLubyte* Extensions, const char* Name)
@@ -331,7 +334,18 @@ void lcInitializeGLExtensions(const QGLContext* Context)
 #endif
 		gSupportsShaderObjects = true;
 	}
-	
+
+#ifndef LC_OPENGLES
+	if (VersionMajor > 3 || (VersionMajor == 3 && VersionMinor >= 2))
+	{
+#ifdef LC_LOAD_GLEXTENSIONS
+		lcTexImage2DMultisample = (PFNGLTEXIMAGE2DMULTISAMPLEPROC)Context->getProcAddress("glTexImage2DMultisample");
+#endif
+
+		gSupportsTexImage2DMultisample = true;
+	}
+#endif
+
 #ifdef LC_OPENGLES
 	gSupportsVertexBufferObject = true;
 	gSupportsFramebufferObjectARB = true;
