@@ -1,5 +1,5 @@
-#ifndef _LC_GLOBAL_H_
-#define _LC_GLOBAL_H_
+#ifndef LC_GLOBAL_H
+#define LC_GLOBAL_H
 
 #include <QtGlobal>
 #include <QWidget>
@@ -8,7 +8,7 @@
 #include <QtGui>
 #include <QPrinter>
 
-#if !defined(EGL_VERSION_1_0) && !defined(GL_ES_VERSION_2_0) && !defined(GL_ES_VERSION_3_0)
+#if !defined(EGL_VERSION_1_0) && !defined(GL_ES_VERSION_2_0) && !defined(GL_ES_VERSION_3_0) && !defined(QT_OPENGL_ES)
 #undef GL_LINES_ADJACENCY_EXT
 #undef GL_LINE_STRIP_ADJACENCY_EXT
 #undef GL_TRIANGLES_ADJACENCY_EXT
@@ -21,18 +21,6 @@
 // Old defines and declarations.
 #define LC_MAXPATH 1024
 
-#define LC_POINTER_TO_INT(p) ((lcint32) (quintptr) (p))
-
-typedef qint8 lcint8;
-typedef quint8 lcuint8;
-typedef qint16 lcint16;
-typedef quint16 lcuint16;
-typedef qint32 lcint32;
-typedef quint32 lcuint32;
-typedef qint64 lcint64;
-typedef quint64 lcuint64;
-typedef quintptr lcuintptr;
-
 #ifdef Q_OS_WIN
 char* strcasestr(const char *s, const char *find);
 #else
@@ -41,10 +29,10 @@ char* strlwr(char* string);
 #endif
 
 // Version number.
-#define LC_VERSION_MAJOR 17
-#define LC_VERSION_MINOR 07
+#define LC_VERSION_MAJOR 18
+#define LC_VERSION_MINOR 01
 #define LC_VERSION_PATCH 0
-#define LC_VERSION_TEXT "17.07"
+#define LC_VERSION_TEXT "18.01"
 
 // Forward declarations.
 class Project;
@@ -75,4 +63,4 @@ class lcFile;
 class lcMemFile;
 class lcDiskFile;
 
-#endif // _LC_GLOBAL_H_
+#endif // LC_GLOBAL_H
