@@ -1,5 +1,4 @@
-#ifndef _LC_LIBRARY_H_
-#define _LC_LIBRARY_H_
+#pragma once
 
 #include "lc_context.h"
 #include "lc_mesh.h"
@@ -16,6 +15,13 @@ enum lcZipFileType
 	LC_NUM_ZIPFILES
 };
 
+enum lcLibraryFolderType
+{
+	LC_FOLDER_UNOFFICIAL,
+	LC_FOLDER_OFFICIAL,
+	LC_NUM_FOLDERTYPES
+};
+
 struct lcLibraryMeshVertex
 {
 	lcVector3 Position;
@@ -34,7 +40,7 @@ struct lcLibraryMeshVertexTextured
 class lcLibraryMeshSection
 {
 public:
-	lcLibraryMeshSection(lcMeshPrimitiveType PrimitiveType, lcuint32 Color, lcTexture* Texture)
+	lcLibraryMeshSection(lcMeshPrimitiveType PrimitiveType, quint32 Color, lcTexture* Texture)
 		: mIndices(1024, 1024)
 	{
 		mPrimitiveType = PrimitiveType;
@@ -47,9 +53,9 @@ public:
 	}
 
 	lcMeshPrimitiveType mPrimitiveType;
-	lcuint32 mColor;
+	quint32 mColor;
 	lcTexture* mTexture;
-	lcArray<lcuint32> mIndices;
+	lcArray<quint32> mIndices;
 };
 
 struct lcLibraryTextureMap
@@ -68,6 +74,13 @@ enum lcMeshDataType
 	LC_NUM_MESHDATA_TYPES
 };
 
+enum class lcPrimitiveState
+{
+	NOT_LOADED,
+	LOADING,
+	LOADED
+};
+
 class lcLibraryMeshData
 {
 public:
@@ -92,17 +105,17 @@ public:
 		return true;
 	}
 
-	lcLibraryMeshSection* AddSection(lcMeshDataType MeshDataType, lcMeshPrimitiveType PrimitiveType, lcuint32 ColorCode, lcTexture* Texture);
-	lcuint32 AddVertex(lcMeshDataType MeshDataType, const lcVector3& Position, bool Optimize);
-	lcuint32 AddVertex(lcMeshDataType MeshDataType, const lcVector3& Position, const lcVector3& Normal, bool Optimize);
-	lcuint32 AddTexturedVertex(lcMeshDataType MeshDataType, const lcVector3& Position, const lcVector2& TexCoord, bool Optimize);
-	lcuint32 AddTexturedVertex(lcMeshDataType MeshDataType, const lcVector3& Position, const lcVector3& Normal, const lcVector2& TexCoord, bool Optimize);
+	lcLibraryMeshSection* AddSection(lcMeshDataType MeshDataType, lcMeshPrimitiveType PrimitiveType, quint32 ColorCode, lcTexture* Texture);
+	quint32 AddVertex(lcMeshDataType MeshDataType, const lcVector3& Position, bool Optimize);
+	quint32 AddVertex(lcMeshDataType MeshDataType, const lcVector3& Position, const lcVector3& Normal, bool Optimize);
+	quint32 AddTexturedVertex(lcMeshDataType MeshDataType, const lcVector3& Position, const lcVector2& TexCoord, bool Optimize);
+	quint32 AddTexturedVertex(lcMeshDataType MeshDataType, const lcVector3& Position, const lcVector3& Normal, const lcVector2& TexCoord, bool Optimize);
 	void AddVertices(lcMeshDataType MeshDataType, int VertexCount, int* BaseVertex, lcLibraryMeshVertex** VertexBuffer);
-	void AddIndices(lcMeshDataType MeshDataType, lcMeshPrimitiveType PrimitiveType, lcuint32 ColorCode, int IndexCount, lcuint32** IndexBuffer);
-	void AddLine(lcMeshDataType MeshDataType, int LineType, lcuint32 ColorCode, bool WindingCCW, const lcVector3* Vertices, bool Optimize);
-	void AddTexturedLine(lcMeshDataType MeshDataType, int LineType, lcuint32 ColorCode, bool WindingCCW, const lcLibraryTextureMap& Map, const lcVector3* Vertices, bool Optimize);
-	void AddMeshData(const lcLibraryMeshData& Data, const lcMatrix44& Transform, lcuint32 CurrentColorCode, bool InvertWinding, bool InvertNormals, lcLibraryTextureMap* TextureMap, lcMeshDataType OverrideDestIndex);
-	void AddMeshDataNoDuplicateCheck(const lcLibraryMeshData& Data, const lcMatrix44& Transform, lcuint32 CurrentColorCode, bool InvertWinding, bool InvertNormals, lcLibraryTextureMap* TextureMap, lcMeshDataType OverrideDestIndex);
+	void AddIndices(lcMeshDataType MeshDataType, lcMeshPrimitiveType PrimitiveType, quint32 ColorCode, int IndexCount, quint32** IndexBuffer);
+	void AddLine(lcMeshDataType MeshDataType, int LineType, quint32 ColorCode, bool WindingCCW, const lcVector3* Vertices, bool Optimize);
+	void AddTexturedLine(lcMeshDataType MeshDataType, int LineType, quint32 ColorCode, bool WindingCCW, const lcLibraryTextureMap& Map, const lcVector3* Vertices, bool Optimize);
+	void AddMeshData(const lcLibraryMeshData& Data, const lcMatrix44& Transform, quint32 CurrentColorCode, bool InvertWinding, bool InvertNormals, lcLibraryTextureMap* TextureMap, lcMeshDataType OverrideDestIndex);
+	void AddMeshDataNoDuplicateCheck(const lcLibraryMeshData& Data, const lcMatrix44& Transform, quint32 CurrentColorCode, bool InvertWinding, bool InvertNormals, lcLibraryTextureMap* TextureMap, lcMeshDataType OverrideDestIndex);
 	void TestQuad(int* QuadIndices, const lcVector3* Vertices);
 	void ResequenceQuad(int* QuadIndices, int a, int b, int c, int d);
 
@@ -114,19 +127,19 @@ public:
 class lcLibraryPrimitive
 {
 public:
-	lcLibraryPrimitive(const char* Name, lcZipFileType ZipFileType,lcuint32 ZipFileIndex, bool Stud, bool SubFile)
+	lcLibraryPrimitive(const char* Name, lcZipFileType ZipFileType,quint32 ZipFileIndex, bool Stud, bool SubFile)
 	{
 		strncpy(mName, Name, sizeof(mName));
 		mName[sizeof(mName) - 1] = 0;
 
 		mZipFileType = ZipFileType;
 		mZipFileIndex = ZipFileIndex;
-		mLoaded = false;
+		mState = lcPrimitiveState::NOT_LOADED;
 		mStud = Stud;
 		mSubFile = SubFile;
 	}
 
-	void SetZipFile(lcZipFileType ZipFileType,lcuint32 ZipFileIndex)
+	void SetZipFile(lcZipFileType ZipFileType,quint32 ZipFileIndex)
 	{
 		mZipFileType = ZipFileType;
 		mZipFileIndex = ZipFileIndex;
@@ -134,8 +147,8 @@ public:
 
 	char mName[LC_MAXPATH];
 	lcZipFileType mZipFileType;
-	lcuint32 mZipFileIndex;
-	bool mLoaded;
+	quint32 mZipFileIndex;
+	lcPrimitiveState mState;
 	bool mStud;
 	bool mSubFile;
 	lcLibraryMeshData mMeshData;
@@ -149,11 +162,12 @@ public:
 	lcPiecesLibrary();
 	~lcPiecesLibrary();
 
-	bool Load(const QString& LibraryPath);
+	bool Load(const QString& LibraryPath, bool ShowProgress);
 	void Unload();
 	void RemoveTemporaryPieces();
 	void RemovePiece(PieceInfo* Info);
 
+	void RenamePiece(PieceInfo* Info, const char* NewName);
 	PieceInfo* FindPiece(const char* PieceName, Project* Project, bool CreatePlaceholder, bool SearchProjectFolder);
 	void LoadPieceInfo(PieceInfo* Info, bool Wait, bool Priority);
 	void ReleasePieceInfo(PieceInfo* Info);
@@ -165,6 +179,8 @@ public:
 	lcTexture* FindTexture(const char* TextureName, Project* CurrentProject, bool SearchProjectFolder);
 	bool LoadTexture(lcTexture* Texture);
 	void ReleaseTexture(lcTexture* Texture);
+	void QueueTextureUpload(lcTexture* Texture);
+	void UploadTextures();
 
 	bool PieceInCategory(PieceInfo* Info, const char* CategoryKeywords) const;
 	void GetCategoryEntries(int CategoryIndex, bool GroupPieces, lcArray<PieceInfo*>& SinglePieces, lcArray<PieceInfo*>& GroupedPieces);
@@ -174,23 +190,23 @@ public:
 
 	bool IsPrimitive(const char* Name) const
 	{
-		return FindPrimitiveIndex(Name) != -1;
+		return mPrimitives.find(Name) != mPrimitives.end();
 	}
 
 	void SetOfficialPieces()
 	{
 		if (mZipFiles[LC_ZIPFILE_OFFICIAL])
-			mNumOfficialPieces = mPieces.GetSize();
+			mNumOfficialPieces = mPieces.size();
 	}
 
-	bool ReadMeshData(lcFile& File, const lcMatrix44& CurrentTransform, lcuint32 CurrentColorCode, bool InvertWinding, lcArray<lcLibraryTextureMap>& TextureStack, lcLibraryMeshData& MeshData, lcMeshDataType MeshDataType, bool Optimize, Project* CurrentProject, bool SearchProjectFolder);
+	bool ReadMeshData(lcFile& File, const lcMatrix44& CurrentTransform, quint32 CurrentColorCode, bool InvertWinding, lcArray<lcLibraryTextureMap>& TextureStack, lcLibraryMeshData& MeshData, lcMeshDataType MeshDataType, bool Optimize, Project* CurrentProject, bool SearchProjectFolder);
 	lcMesh* CreateMesh(PieceInfo* Info, lcLibraryMeshData& MeshData);
 	void ReleaseBuffers(lcContext* Context);
 	void UpdateBuffers(lcContext* Context);
 	void UnloadUnusedParts();
 
-	lcArray<PieceInfo*> mPieces;
-	lcArray<lcLibraryPrimitive*> mPrimitives;
+	std::map<std::string, PieceInfo*> mPieces;
+	std::map<std::string, lcLibraryPrimitive*> mPrimitives;
 	int mNumOfficialPieces;
 
 	lcArray<lcTexture*> mTextures;
@@ -207,29 +223,40 @@ signals:
 protected:
 	bool OpenArchive(const QString& FileName, lcZipFileType ZipFileType);
 	bool OpenArchive(lcFile* File, const QString& FileName, lcZipFileType ZipFileType);
-	bool OpenDirectory(const QDir& LibraryDir);
+	bool OpenDirectory(const QDir& LibraryDir, bool ShowProgress);
 	void ReadArchiveDescriptions(const QString& OfficialFileName, const QString& UnofficialFileName);
+	void ReadDirectoryDescriptions(const QFileInfoList (&FileLists)[LC_NUM_FOLDERTYPES], bool ShowProgress);
 
-	bool ReadCacheFile(const QString& FileName, lcMemFile& CacheFile);
-	bool WriteCacheFile(const QString& FileName, lcMemFile& CacheFile);
+	bool ReadArchiveCacheFile(const QString& FileName, lcMemFile& CacheFile);
+	bool WriteArchiveCacheFile(const QString& FileName, lcMemFile& CacheFile);
 	bool LoadCacheIndex(const QString& FileName);
-	bool SaveCacheIndex(const QString& FileName);
+	bool SaveArchiveCacheIndex(const QString& FileName);
 	bool LoadCachePiece(PieceInfo* Info);
 	bool SaveCachePiece(PieceInfo* Info);
+	bool ReadDirectoryCacheFile(const QString& FileName, lcMemFile& CacheFile);
+	bool WriteDirectoryCacheFile(const QString& FileName, lcMemFile& CacheFile);
 
-	int FindPrimitiveIndex(const char* Name) const;
-	bool LoadPrimitive(int PrimitiveIndex);
+	lcLibraryPrimitive* FindPrimitive(const char* Name) const
+	{
+		const auto PrimitiveIt = mPrimitives.find(Name);
+		return PrimitiveIt != mPrimitives.end() ? PrimitiveIt->second : nullptr;
+	}
+
+	bool LoadPrimitive(lcLibraryPrimitive* Primitive);
 
 	QMutex mLoadMutex;
 	QList<QFuture<void>> mLoadFutures;
 	QList<PieceInfo*> mLoadQueue;
 
+	QMutex mTextureMutex;
+	std::vector<lcTexture*> mTextureUploads;
+
 	QString mCachePath;
 	qint64 mArchiveCheckSum[4];
 	QString mLibraryFileName;
 	QString mUnofficialFileName;
 	lcZipFile* mZipFiles[LC_NUM_ZIPFILES];
 	bool mHasUnofficial;
+	bool mCancelLoading;
 };
 
-#endif // _LC_LIBRARY_H_
