@@ -1,20 +1,19 @@
-#ifndef _LC_MATH_H_
-#define _LC_MATH_H_
+#pragma once
 
 #include <math.h>
 #include <float.h>
 
-#define LC_DTOR 0.017453f
-#define LC_RTOD 57.29578f
-#define LC_PI   3.141592f
-#define LC_2PI  6.283185f
+#define LC_DTOR (static_cast<float>(M_PI / 180))
+#define LC_RTOD (static_cast<float>(180 / M_PI))
+#define LC_PI (static_cast<float>(M_PI))
+#define LC_2PI (static_cast<float>(2 * M_PI))
 
 #define LC_RGB(r,g,b) LC_RGBA(r,g,b,255)
-#define LC_RGBA(r,g,b,a) ((lcuint32)(((lcuint8) (r) | ((lcuint16) (g) << 8)) | (((lcuint32) (lcuint8) (b)) << 16) | (((lcuint32) (lcuint8) (a)) << 24))) 
-#define LC_RGBA_RED(rgba)   ((lcuint8)(((rgba) >>  0) & 0xff))
-#define LC_RGBA_GREEN(rgba) ((lcuint8)(((rgba) >>  8) & 0xff))
-#define LC_RGBA_BLUE(rgba)  ((lcuint8)(((rgba) >> 16) & 0xff))
-#define LC_RGBA_ALPHA(rgba) ((lcuint8)(((rgba) >> 24) & 0xff))
+#define LC_RGBA(r,g,b,a) ((quint32)(((quint8) (r) | ((quint16) (g) << 8)) | (((quint32) (quint8) (b)) << 16) | (((quint32) (quint8) (a)) << 24))) 
+#define LC_RGBA_RED(rgba)   ((quint8)(((rgba) >>  0) & 0xff))
+#define LC_RGBA_GREEN(rgba) ((quint8)(((rgba) >>  8) & 0xff))
+#define LC_RGBA_BLUE(rgba)  ((quint8)(((rgba) >> 16) & 0xff))
+#define LC_RGBA_ALPHA(rgba) ((quint8)(((rgba) >> 24) & 0xff))
 #define LC_FLOATRGB(f) LC_RGB(f[0]*255, f[1]*255, f[2]*255)
 
 template<typename T>
@@ -364,13 +363,60 @@ inline bool operator!=(const lcVector3& a, const lcVector3& b)
 
 #ifndef QT_NO_DEBUG
 
-inline QDebug operator<<(QDebug d, const lcVector3& v)
+inline QDebug operator<<(QDebug Debug, const lcVector3& v)
 {
-	return d << v.x << v.y << v.z;
+	QDebugStateSaver Saver(Debug);
+	Debug.nospace() << '(' << v.x << ", " << v.y << ", " << v.z << ')';
+	return Debug;
+}
+
+inline QDebug operator<<(QDebug Debug, const lcVector4& v)
+{
+	QDebugStateSaver Saver(Debug);
+	Debug.nospace() << '(' << v.x << ", " << v.y << ", " << v.z << ", " << v.w << ')';
+	return Debug;
+}
+
+inline QDebug operator<<(QDebug Debug, const lcMatrix33& m)
+{
+	QDebugStateSaver Saver(Debug);
+	Debug.nospace() << '[' << m[0] << ", " << m[1] << ", " << m[2] << ']';
+	return Debug;
+}
+
+inline QDebug operator<<(QDebug Debug, const lcMatrix44& m)
+{
+	QDebugStateSaver Saver(Debug);
+	Debug.nospace() << '[' << m[0] << ", " << m[1] << ", " << m[2] << ", " << m[3] << ']';
+	return Debug;
 }
 
 #endif
 
+inline QDataStream& operator<<(QDataStream& Stream, const lcVector3& v)
+{
+	Stream << v.x << v.y << v.z;
+	return Stream;
+}
+
+inline QDataStream& operator>>(QDataStream& Stream, lcVector3& v)
+{
+	Stream >> v.x >> v.y >> v.z;
+	return Stream;
+}
+
+inline QDataStream& operator<<(QDataStream& Stream, const lcVector4& v)
+{
+	Stream << v.x << v.y << v.z << v.w;
+	return Stream;
+}
+
+inline QDataStream& operator >> (QDataStream& Stream, lcVector4& v)
+{
+	Stream >> v.x >> v.y >> v.z >> v.w;
+	return Stream;
+}
+
 inline void lcVector3::Normalize()
 {
 	float InvLength = 1.0f / Length();
@@ -527,7 +573,7 @@ inline lcVector4& operator/=(lcVector4& a, float b)
 	return a;
 }
 
-inline qint32 lcPackNormal(const lcVector3& Normal)
+inline quint32 lcPackNormal(const lcVector3& Normal)
 {
 	quint32 Packed = 0;
 
@@ -538,7 +584,7 @@ inline qint32 lcPackNormal(const lcVector3& Normal)
 	return Packed;
 }
 
-inline lcVector3 lcUnpackNormal(qint32 Packed)
+inline lcVector3 lcUnpackNormal(quint32 Packed)
 {
 	lcVector3 Normal;
 
@@ -554,21 +600,21 @@ inline lcVector3 lcVector3LDrawToLeoCAD(const lcVector3& Vector)
 	return lcVector3(Vector[0], Vector[2], -Vector[1]);
 }
 
-inline lcVector3 lcVector3FromColor(lcuint32 Color)
+inline lcVector3 lcVector3FromColor(quint32 Color)
 {
 	lcVector3 v(LC_RGBA_RED(Color), LC_RGBA_GREEN(Color), LC_RGBA_BLUE(Color));
 	v /= 255.0f;
 	return v;
 }
 
-inline lcVector4 lcVector4FromColor(lcuint32 Color)
+inline lcVector4 lcVector4FromColor(quint32 Color)
 {
 	lcVector4 v(LC_RGBA_RED(Color), LC_RGBA_GREEN(Color), LC_RGBA_BLUE(Color), LC_RGBA_ALPHA(Color));
 	v /= 255.0f;
 	return v;
 }
 
-inline lcuint32 lcColorFromVector3(const lcVector3& Color)
+inline quint32 lcColorFromVector3(const lcVector3& Color)
 {
 	return LC_RGB(Color[0] * 255, Color[1] * 255, Color[2] * 255);
 }
@@ -755,6 +801,17 @@ inline lcMatrix33 lcMatrix33FromAxisAngle(const lcVector3& Axis, const float Rad
 	return m;
 }
 
+inline lcMatrix33 lcMatrix33Transpose(const lcMatrix33& m)
+{
+	lcMatrix33 t;
+
+	t.r[0] = lcVector3(m[0][0], m[1][0], m[2][0]);
+	t.r[1] = lcVector3(m[0][1], m[1][1], m[2][1]);
+	t.r[2] = lcVector3(m[0][2], m[1][2], m[2][2]);
+
+	return t;
+}
+
 inline lcMatrix33 lcMatrix33AffineInverse(const lcMatrix33& m)
 {
 	lcMatrix33 Inv;
@@ -1309,9 +1366,9 @@ inline lcMatrix44 lcMatrix44LDrawToLeoCAD(const lcMatrix44& Matrix)
 {
 	lcMatrix44 m;
 
-	m.r[0] = lcVector4(Matrix[0][0], Matrix[2][0], -Matrix[1][0], 0.0f);
-	m.r[1] = lcVector4(Matrix[0][2], Matrix[2][2], -Matrix[1][2], 0.0f);
-	m.r[2] = lcVector4(-Matrix[0][1], -Matrix[2][1], Matrix[1][1], 0.0f);
+	m.r[0] = lcVector4(Matrix[0][0], Matrix[0][2], -Matrix[0][1], 0.0f);
+	m.r[1] = lcVector4(Matrix[2][0], Matrix[2][2], -Matrix[2][1], 0.0f);
+	m.r[2] = lcVector4(-Matrix[1][0], -Matrix[1][2], Matrix[1][1], 0.0f);
 	m.r[3] = lcVector4(Matrix[3][0], Matrix[3][2], -Matrix[3][1], 1.0f);
 
 	return m;
@@ -1484,36 +1541,46 @@ inline void lcGetFrustumPlanes(const lcMatrix44& WorldView, const lcMatrix44& Pr
 	}
 }
 
-inline lcVector3 lcZoomExtents(const lcVector3& Position, const lcMatrix44& WorldView, const lcMatrix44& Projection, const lcVector3* Points, int NumPoints)
+inline std::tuple<lcVector3, float> lcZoomExtents(const lcVector3& Position, const lcMatrix44& WorldView, const lcMatrix44& Projection, const lcVector3* Points, int NumPoints)
 {
 	if (!NumPoints)
-		return Position;
+		return std::make_tuple(Position, 2500.0f);
 
 	lcVector4 Planes[6];
 	lcGetFrustumPlanes(WorldView, Projection, Planes);
 
 	lcVector3 Front(WorldView[0][2], WorldView[1][2], WorldView[2][2]);
 
-	// Calculate the position that is as close as possible to the model and has all pieces visible.
 	float SmallestDistance = FLT_MAX;
 
-	for (int p = 0; p < 4; p++)
+	for (int PlaneIdx = 0; PlaneIdx < 4; PlaneIdx++)
 	{
-		lcVector3 Plane(Planes[p][0], Planes[p][1], Planes[p][2]);
+		lcVector3 Plane(Planes[PlaneIdx][0], Planes[PlaneIdx][1], Planes[PlaneIdx][2]);
 		float ep = lcDot(Position, Plane);
 		float fp = lcDot(Front, Plane);
 
-		for (int j = 0; j < NumPoints; j++)
+		for (int PointIdx = 0; PointIdx < NumPoints; PointIdx++)
 		{
-			// Intersect the camera line with the plane that contains this point, NewEye = Eye + u * (Target - Eye)
-			float u = (ep - lcDot(Points[j], Plane)) / fp;
+			float u = (ep - lcDot(Points[PointIdx], Plane)) / fp;
 
 			if (u < SmallestDistance)
 				SmallestDistance = u;
 		}
 	}
 
-	return Position - (Front * SmallestDistance);
+	lcVector3 NewPosition = Position - (Front * SmallestDistance);
+
+	float FarDistance = 2500.0f;
+
+	for (int PointIdx = 0; PointIdx < NumPoints; PointIdx++)
+	{
+		float Distance = lcDot(Points[PointIdx], Front);
+
+		if (Distance > FarDistance)
+			FarDistance = Distance;
+	}
+
+	return std::make_tuple(NewPosition, FarDistance + lcDot(NewPosition, Front));
 }
 
 inline void lcClosestPointsBetweenLines(const lcVector3& Line1a, const lcVector3& Line1b, const lcVector3& Line2a, const lcVector3& Line2b, lcVector3* Intersection1, lcVector3* Intersection2)
@@ -1952,4 +2019,3 @@ bool SphereIntersectsVolume(const Vector3& Center, float Radius, const Vector4*
 	return true;
 }*/
 
-#endif // _LC_MATH_H_
