@@ -36,7 +36,7 @@ lcMesh::~lcMesh()
 		delete[] mLods[LodIdx].Sections;
 }
 
-void lcMesh::Create(lcuint16 NumSections[LC_NUM_MESH_LODS], int NumVertices, int NumTexturedVertices, int NumIndices)
+void lcMesh::Create(quint16 NumSections[LC_NUM_MESH_LODS], int NumVertices, int NumTexturedVertices, int NumIndices)
 {
 	for (int LodIdx = 0; LodIdx < LC_NUM_MESH_LODS; LodIdx++)
 	{
@@ -66,7 +66,7 @@ void lcMesh::Create(lcuint16 NumSections[LC_NUM_MESH_LODS], int NumVertices, int
 
 void lcMesh::CreateBox()
 {
-	lcuint16 NumSections[LC_NUM_MESH_LODS];
+	quint16 NumSections[LC_NUM_MESH_LODS];
 	memset(NumSections, 0, sizeof(NumSections));
 	NumSections[LC_MESH_LOD_HIGH] = 2;
 
@@ -79,7 +79,7 @@ void lcMesh::CreateBox()
 	mBoundingBox.Max = Max;
 
 	lcVertex* Verts = (lcVertex*)mVertexData;
-	lcuint16* Indices = (lcuint16*)mIndexData;
+	quint16* Indices = (quint16*)mIndexData;
 
 	Verts[0].Position = lcVector3(Min[0], Min[1], Min[2]);
 	Verts[0].Normal = lcPackNormal(lcVector3(0.0f, 0.0f, -1.0f));
@@ -252,7 +252,20 @@ void lcMesh::ExportPOVRay(lcFile& File, const char* MeshName, const char** Color
 {
 	char Line[1024];
 
-	sprintf(Line, "#declare lc_%s = union {\n", MeshName);
+	int NumSections = 0;
+
+	for (int SectionIdx = 0; SectionIdx < mLods[LC_MESH_LOD_HIGH].NumSections; SectionIdx++)
+	{
+		lcMeshSection* Section = &mLods[LC_MESH_LOD_HIGH].Sections[SectionIdx];
+
+		if (Section->PrimitiveType == LC_MESH_TRIANGLES || Section->PrimitiveType == LC_MESH_TEXTURED_TRIANGLES)
+			NumSections++;
+	}
+
+	if (NumSections > 1)
+		sprintf(Line, "#declare lc_%s = union {\n", MeshName);
+	else
+		sprintf(Line, "#declare lc_%s = mesh {\n", MeshName);
 	File.WriteLine(Line);
 
 	lcVertex* Verts = (lcVertex*)mVertexData;
@@ -266,15 +279,20 @@ void lcMesh::ExportPOVRay(lcFile& File, const char* MeshName, const char** Color
 
 		IndexType* Indices = (IndexType*)mIndexData + Section->IndexOffset / sizeof(IndexType);
 
-		File.WriteLine(" mesh {\n");
+		if (NumSections > 1)
+			File.WriteLine(" mesh {\n");
 
 		for (int Idx = 0; Idx < Section->NumIndices; Idx += 3)
 		{
-			lcVector3& v1 = Verts[Indices[Idx]].Position;
-			lcVector3& v2 = Verts[Indices[Idx + 1]].Position;
-			lcVector3& v3 = Verts[Indices[Idx + 2]].Position;
+			const lcVector3 v1 = Verts[Indices[Idx]].Position / 25.0f;
+			const lcVector3 v2 = Verts[Indices[Idx + 1]].Position / 25.0f;
+			const lcVector3 v3 = Verts[Indices[Idx + 2]].Position / 25.0f;
+			const lcVector3 n1 = lcUnpackNormal(Verts[Indices[Idx]].Normal);
+			const lcVector3 n2 = lcUnpackNormal(Verts[Indices[Idx + 1]].Normal);
+			const lcVector3 n3 = lcUnpackNormal(Verts[Indices[Idx + 2]].Normal);
 
-			sprintf(Line, "  triangle { <%.2f, %.2f, %.2f>, <%.2f, %.2f, %.2f>, <%.2f, %.2f, %.2f> }\n", -v1.y / 25.0f, -v1.x / 25.0f, v1.z / 25.0f, -v2.y / 25.0f, -v2.x / 25.0f, v2.z / 25.0f, -v3.y / 25.0f, -v3.x / 25.0f, v3.z / 25.0f);
+			sprintf(Line, "  smooth_triangle { <%.2f, %.2f, %.2f>, <%.2f, %.2f, %.2f>, <%.2f, %.2f, %.2f>, <%.2f, %.2f, %.2f>, <%.2f, %.2f, %.2f>, <%.2f, %.2f, %.2f> }\n",
+			        -v1.y, -v1.x, v1.z, -n1.y, -n1.x, n1.z, -v2.y, -v2.x, v2.z, -n2.y, -n2.x, n2.z, -v3.y, -v3.x, v3.z, -n3.y, -n3.x, n3.z);
 			File.WriteLine(Line);
 		}
 
@@ -284,8 +302,11 @@ void lcMesh::ExportPOVRay(lcFile& File, const char* MeshName, const char** Color
 			File.WriteLine(Line);
 		}
 
-		File.WriteLine(" }\n");
+		if (NumSections > 1)
+			File.WriteLine(" }\n");
 	}
+
+	File.WriteLine("}\n\n");
 }
 
 void lcMesh::ExportPOVRay(lcFile& File, const char* MeshName, const char** ColorTable)
@@ -323,7 +344,7 @@ void lcMesh::ExportWavefrontIndices(lcFile& File, int DefaultColorIndex, int Ver
 			long int idx3 = Indices[Idx + 2] + VertexOffset;
 
 			if (idx1 != idx2 && idx1 != idx3 && idx2 != idx3)
-				sprintf(Line, "f %ld %ld %ld\n", idx1, idx2, idx3);
+				sprintf(Line, "f %ld//%ld %ld//%ld %ld//%ld\n", idx1, idx1, idx2, idx2, idx3, idx3);
 			File.WriteLine(Line);
 		}
 	}
@@ -348,8 +369,8 @@ bool lcMesh::FileLoad(lcMemFile& File)
 	mBoundingBox.Max = File.ReadVector3();
 	mRadius = File.ReadFloat();
 
-	lcuint32 NumVertices, NumTexturedVertices, NumIndices;
-	lcuint16 NumLods, NumSections[LC_NUM_MESH_LODS];
+	quint32 NumVertices, NumTexturedVertices, NumIndices;
+	quint16 NumLods, NumSections[LC_NUM_MESH_LODS];
 
 	if (!File.ReadU32(&NumVertices, 1) || !File.ReadU32(&NumTexturedVertices, 1) || !File.ReadU32(&NumIndices, 1))
 		return false;
@@ -365,8 +386,8 @@ bool lcMesh::FileLoad(lcMemFile& File)
 		{
 			lcMeshSection& Section = mLods[LodIdx].Sections[SectionIdx];
 
-			lcuint32 ColorCode, IndexOffset;
-			lcuint16 PrimtiveType, Length;
+			quint32 ColorCode, IndexOffset;
+			quint16 PrimtiveType, Length;
 
 			if (!File.ReadU32(&ColorCode, 1) || !File.ReadU32(&IndexOffset, 1) || !File.ReadU32(&NumIndices, 1) || !File.ReadU16(&PrimtiveType, 1))
 				return false;
@@ -398,9 +419,9 @@ bool lcMesh::FileLoad(lcMemFile& File)
 
 	File.ReadBuffer(mVertexData, mNumVertices * sizeof(lcVertex) + mNumTexturedVertices * sizeof(lcVertexTextured));
 	if (mIndexType == GL_UNSIGNED_SHORT)
-		File.ReadU16((lcuint16*)mIndexData, mIndexDataSize / 2);
+		File.ReadU16((quint16*)mIndexData, mIndexDataSize / 2);
 	else
-		File.ReadU32((lcuint32*)mIndexData, mIndexDataSize / 4);
+		File.ReadU32((quint32*)mIndexData, mIndexDataSize / 4);
 
 	return true;
 }
@@ -435,7 +456,7 @@ bool lcMesh::FileSave(lcMemFile& File)
 
 			if (Section.Texture)
 			{
-				lcuint16 Length = (lcuint16)strlen(Section.Texture->mName);
+				quint16 Length = (quint16)strlen(Section.Texture->mName);
 				File.WriteU16(Length);
 				File.WriteBuffer(Section.Texture->mName, Length);
 			}
@@ -446,9 +467,9 @@ bool lcMesh::FileSave(lcMemFile& File)
 
 	File.WriteBuffer(mVertexData, mNumVertices * sizeof(lcVertex) + mNumTexturedVertices * sizeof(lcVertexTextured));
 	if (mIndexType == GL_UNSIGNED_SHORT)
-		File.WriteU16((lcuint16*)mIndexData, mIndexDataSize / 2);
+		File.WriteU16((quint16*)mIndexData, mIndexDataSize / 2);
 	else
-		File.WriteU32((lcuint32*)mIndexData, mIndexDataSize / 4);
+		File.WriteU32((quint32*)mIndexData, mIndexDataSize / 4);
 
 	return true;
 }
