@@ -1,5 +1,4 @@
-#ifndef _LC_MESH_H_
-#define _LC_MESH_H_
+#pragma once
 
 #include "lc_math.h"
 
@@ -57,7 +56,7 @@ public:
 	lcMesh();
 	~lcMesh();
 
-	void Create(lcuint16 NumSections[LC_NUM_MESH_LODS], int NumVertices, int NumTexturedVertices, int NumIndices);
+	void Create(quint16 NumSections[LC_NUM_MESH_LODS], int NumVertices, int NumTexturedVertices, int NumIndices);
 	void CreateBox();
 
 	bool FileLoad(lcMemFile& File);
@@ -117,4 +116,3 @@ struct lcRenderMesh
 
 extern lcMesh* gPlaceholderMesh;
 
-#endif // _LC_MESH_H_
