@@ -1,5 +1,4 @@
-#ifndef _LC_MODEL_H_
-#define _LC_MODEL_H_
+#pragma once
 
 #include "lc_math.h"
 #include "object.h"
@@ -21,6 +20,14 @@
 
 class lcGLWidget;
 
+enum class lcSelectionMode
+{
+	SINGLE,
+	PIECE,
+	COLOR,
+	PIECE_COLOR
+};
+
 enum lcTransformType
 {
 	LC_TRANSFORM_ABSOLUTE_TRANSLATION,
@@ -145,6 +152,11 @@ public:
 		return mProperties.mName;
 	}
 
+	void SetDescription(const QString& Description)
+	{
+		mProperties.mDescription = Description;
+	}
+
 	const QStringList& GetFileLines() const
 	{
 		return mFileLines;
@@ -182,6 +194,7 @@ public:
 	void ShowSelectedPiecesEarlier();
 	void ShowSelectedPiecesLater();
 	void SetPieceSteps(const QList<QPair<lcPiece*, lcStep>>& PieceSteps);
+	void RenamePiece(PieceInfo* Info);
 
 	void MoveSelectionToModel(lcModel* Model);
 	void InlineSelectedModels();
@@ -199,6 +212,7 @@ public:
 	void LoadLDraw(QIODevice& Device, Project* Project);
 	bool LoadBinary(lcFile* File);
 	bool LoadLDD(const QString& FileData);
+	bool LoadInventory(const QByteArray& Inventory);
 	void SplitMPD(QIODevice& Device);
 	void Merge(lcModel* Other);
 
@@ -236,17 +250,20 @@ public:
 	lcObject* GetFocusObject() const;
 	bool GetSelectionCenter(lcVector3& Center) const;
 	bool GetPiecesBoundingBox(lcVector3& Min, lcVector3& Max) const;
-	void GetPartsList(int DefaultColorIndex, lcPartsList& PartsList) const;
+	void GetPartsList(int DefaultColorIndex, bool IncludeSubmodels, lcPartsList& PartsList) const;
 	void GetPartsListForStep(lcStep Step, int DefaultColorIndex, lcPartsList& PartsList) const;
 	void GetModelParts(const lcMatrix44& WorldMatrix, int DefaultColorIndex, lcArray<lcModelPartsEntry>& ModelParts) const;
 	void GetSelectionInformation(int* Flags, lcArray<lcObject*>& Selection, lcObject** Focus) const;
+	lcArray<lcObject*> GetSelectionModePieces(lcPiece* SelectedPiece) const;
 
 	void FocusOrDeselectObject(const lcObjectSection& ObjectSection);
 	void ClearSelection(bool UpdateInterface);
-	void ClearSelectionAndSetFocus(lcObject* Object, lcuint32 Section);
-	void ClearSelectionAndSetFocus(const lcObjectSection& ObjectSection);
-	void SetSelectionAndFocus(const lcArray<lcObject*>& Selection, lcObject* Focus, lcuint32 Section);
-	void AddToSelection(const lcArray<lcObject*>& Objects);
+	void ClearSelectionAndSetFocus(lcObject* Object, quint32 Section, bool EnableSelectionMode);
+	void ClearSelectionAndSetFocus(const lcObjectSection& ObjectSection, bool EnableSelectionMode);
+	void SetSelectionAndFocus(const lcArray<lcObject*>& Selection, lcObject* Focus, quint32 Section, bool EnableSelectionMode);
+	void AddToSelection(const lcArray<lcObject*>& Objects, bool EnableSelectionMode, bool UpdateInterface);
+	void RemoveFromSelection(const lcArray<lcObject*>& Objects);
+	void RemoveFromSelection(const lcObjectSection& ObjectSection);
 	void SelectAllPieces();
 	void InvertSelection();
 
@@ -260,7 +277,6 @@ public:
 	void UndoAction();
 	void RedoAction();
 
-	lcVector3 LockVector(const lcVector3& Vector) const;
 	lcVector3 SnapPosition(const lcVector3& Delta) const;
 	lcVector3 SnapRotation(const lcVector3& Delta) const;
 	lcMatrix33 GetRelativeRotation() const;
@@ -289,6 +305,7 @@ public:
 	void UpdateRollTool(lcCamera* Camera, float Mouse);
 	void ZoomRegionToolClicked(lcCamera* Camera, float AspectRatio, const lcVector3& Position, const lcVector3& TargetPosition, const lcVector3* Corners);
 	void LookAt(lcCamera* Camera);
+	void MoveCamera(lcCamera* Camera, const lcVector3& Direction);
 	void ZoomExtents(lcCamera* Camera, float Aspect);
 	void Zoom(lcCamera* Camera, float Amount);
 
@@ -357,4 +374,3 @@ protected:
 	Q_DECLARE_TR_FUNCTIONS(lcModel);
 };
 
-#endif // _LC_MODEL_H_
