@@ -12,69 +12,9 @@
 
  Q_DECLARE_METATYPE(QList<int>)
 
-static int lcPartSortFunc(PieceInfo* const& a, PieceInfo* const& b)
-{
-	return strcmp(a->m_strDescription, b->m_strDescription);
-}
-
-lcPartSelectionFilterModel::lcPartSelectionFilterModel(QObject* Parent)
-	: QSortFilterProxyModel(Parent)
-{
-	mShowDecoratedParts = lcGetProfileInt(LC_PROFILE_PARTS_LIST_DECORATED);
-}
-
-void lcPartSelectionFilterModel::SetFilter(const QString& Filter)
-{
-	mFilter = Filter.toLatin1();
-	invalidateFilter();
-}
-
-void lcPartSelectionFilterModel::SetShowDecoratedParts(bool Show)
-{
-	if (Show == mShowDecoratedParts)
-		return;
-
-	mShowDecoratedParts = Show;
-
-	invalidateFilter();
-}
-
-bool lcPartSelectionFilterModel::filterAcceptsRow(int SourceRow, const QModelIndex& SourceParent) const
-{
-	Q_UNUSED(SourceParent);
-
-	lcPartSelectionListModel* SourceModel = (lcPartSelectionListModel*)sourceModel();
-	PieceInfo* Info = SourceModel->GetPieceInfo(SourceRow);
-
-	if (!mShowDecoratedParts && Info->IsPatterned())
-		return false;
-
-	if (mFilter.isEmpty())
-		return true;
-
-	char Description[sizeof(Info->m_strDescription)];
-	char* Src = Info->m_strDescription;
-	char* Dst = Description;
-
-	for (;;)
-	{
-		*Dst = *Src;
-
-		if (*Src == ' ' && *(Src + 1) == ' ')
-			Src++;
-		else if (*Src == 0)
-			break;
-
-		Src++;
-		Dst++;
-	}
-
-	return strcasestr(Description, mFilter) || strcasestr(Info->m_strName, mFilter);
-}
-
 void lcPartSelectionItemDelegate::paint(QPainter* Painter, const QStyleOptionViewItem& Option, const QModelIndex& Index) const
 {
-	mListModel->RequestPreview(mFilterModel->mapToSource(Index).row());
+	mListModel->RequestPreview(Index.row());
 	QStyledItemDelegate::paint(Painter, Option, Index);
 }
 
@@ -101,6 +41,7 @@ lcPartSelectionListModel::lcPartSelectionListModel(QObject* Parent)
 	mIconSize = 0;
 	mShowPartNames = lcGetProfileInt(LC_PROFILE_PARTS_LIST_NAMES);
 	mListMode = lcGetProfileInt(LC_PROFILE_PARTS_LIST_LISTMODE);
+	mShowDecoratedParts = lcGetProfileInt(LC_PROFILE_PARTS_LIST_DECORATED);
 
 	int ColorCode = lcGetProfileInt(LC_PROFILE_PARTS_LIST_COLOR);
 	if (ColorCode == -1)
@@ -145,6 +86,8 @@ void lcPartSelectionListModel::Redraw()
 		mParts[PartIdx].second = QPixmap();
 
 	endResetModel();
+
+	SetFilter(mFilter);
 }
 
 void lcPartSelectionListModel::SetColorIndex(int ColorIndex)
@@ -184,8 +127,27 @@ void lcPartSelectionListModel::SetCategory(int CategoryIndex)
 	if (CategoryIndex != -1)
 		Library->GetCategoryEntries(CategoryIndex, false, SingleParts, GroupedParts);
 	else
+	{
 		Library->GetParts(SingleParts);
 
+		lcModel* CurrentModel = lcGetActiveModel();
+
+		for (int PartIdx = 0; PartIdx < SingleParts.GetSize(); )
+		{
+			PieceInfo* Info = SingleParts[PartIdx];
+
+			if (!Info->IsModel() || !Info->GetModel()->IncludesModel(CurrentModel))
+				PartIdx++;
+			else
+				SingleParts.RemoveIndex(PartIdx);
+		}
+	}
+
+	auto lcPartSortFunc=[](PieceInfo* const& a, PieceInfo* const& b)
+	{
+		return strcmp(a->m_strDescription, b->m_strDescription);
+	};
+
 	SingleParts.Sort(lcPartSortFunc);
 	mParts.resize(SingleParts.GetSize());
 
@@ -193,6 +155,8 @@ void lcPartSelectionListModel::SetCategory(int CategoryIndex)
 		mParts[PartIdx] = QPair<PieceInfo*, QPixmap>(SingleParts[PartIdx], QPixmap());
 
 	endResetModel();
+
+	SetFilter(mFilter);
 }
 
 void lcPartSelectionListModel::SetModelsCategory()
@@ -215,6 +179,8 @@ void lcPartSelectionListModel::SetModelsCategory()
 	}
 
 	endResetModel();
+
+	SetFilter(mFilter);
 }
 
 void lcPartSelectionListModel::SetCurrentModelCategory()
@@ -227,12 +193,53 @@ void lcPartSelectionListModel::SetCurrentModelCategory()
 
 	lcModel* CurrentModel = lcGetActiveModel();
 	lcPartsList PartsList;
-	CurrentModel->GetPartsList(gDefaultColor, PartsList);
+	CurrentModel->GetPartsList(gDefaultColor, true, PartsList);
 
 	for (const auto& PartIt : PartsList)
 		mParts.append(QPair<PieceInfo*, QPixmap>((PieceInfo*)PartIt.first, QPixmap()));
 
 	endResetModel();
+
+	SetFilter(mFilter);
+}
+
+void lcPartSelectionListModel::SetFilter(const QString& Filter)
+{
+	mFilter = Filter.toLatin1();
+
+	for (int PartIdx = 0; PartIdx < mParts.size(); PartIdx++)
+	{
+		PieceInfo* Info = mParts[PartIdx].first;
+		bool Visible;
+
+		if (!mShowDecoratedParts && Info->IsPatterned())
+			Visible = false;
+		else if (mFilter.isEmpty())
+			Visible = true;
+		else
+		{
+			char Description[sizeof(Info->m_strDescription)];
+			char* Src = Info->m_strDescription;
+			char* Dst = Description;
+
+			for (;;)
+			{
+				*Dst = *Src;
+
+				if (*Src == ' ' && *(Src + 1) == ' ')
+					Src++;
+				else if (*Src == 0)
+					break;
+
+				Src++;
+				Dst++;
+			}
+
+			Visible = strcasestr(Description, mFilter) || strcasestr(Info->mFileName, mFilter);
+		}
+
+		mListView->setRowHidden(PartIdx, !Visible);
+	}
 }
 
 int lcPartSelectionListModel::rowCount(const QModelIndex& Parent) const
@@ -258,7 +265,7 @@ QVariant lcPartSelectionListModel::data(const QModelIndex& Index, int Role) cons
 			break;
 
 		case Qt::ToolTipRole:
-			return QVariant(QString("%1 (%2)").arg(QString::fromLatin1(Info->m_strDescription), QString::fromLatin1(Info->m_strName)));
+			return QVariant(QString("%1 (%2)").arg(QString::fromLatin1(Info->m_strDescription), QString::fromLatin1(Info->mFileName)));
 
 		case Qt::DecorationRole:
 			if (!mParts[InfoIndex].second.isNull() && mIconSize)
@@ -324,23 +331,29 @@ void lcPartSelectionListModel::PartLoaded(PieceInfo* Info)
 
 void lcPartSelectionListModel::DrawPreview(int InfoIndex)
 {
-	View* View = gMainWindow->GetActiveView();
-	View->MakeCurrent();
-	lcContext* Context = View->mContext;
+	View* ActiveView = gMainWindow->GetActiveView();
+	if (!ActiveView)
+		return;
+
+	ActiveView->MakeCurrent();
+	lcContext* Context = ActiveView->mContext;
 	int Width = mIconSize * 2;
 	int Height = mIconSize * 2;
 
-	if (!Context->BeginRenderToTexture(Width, Height))
+	if (mRenderFramebuffer.first.mWidth != Width || mRenderFramebuffer.first.mHeight != Height)
+	{
+		Context->DestroyRenderFramebuffer(mRenderFramebuffer);
+		mRenderFramebuffer = Context->CreateRenderFramebuffer(Width, Height);
+	}
+
+	if (!mRenderFramebuffer.first.IsValid())
 		return;
 
 	float Aspect = (float)Width / (float)Height;
 	Context->SetViewport(0, 0, Width, Height);
 
-	lcMatrix44 ProjectionMatrix = lcMatrix44Perspective(20.0f, Aspect, 1.0f, 12500.0f);
-	lcMatrix44 ViewMatrix;
-
 	Context->SetDefaultState();
-	Context->SetProjectionMatrix(ProjectionMatrix);
+	Context->BindFramebuffer(mRenderFramebuffer.first);
 
 	lcPiecesLibrary* Library = lcGetPiecesLibrary();
 	PieceInfo* Info = mParts[InfoIndex].first;
@@ -348,8 +361,11 @@ void lcPartSelectionListModel::DrawPreview(int InfoIndex)
 	glClearColor(1.0f, 1.0f, 1.0f, 0.0f);
 	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 		
-	lcVector3 CameraPosition(-100.0f, -100.0f, 75.0f);
-	Info->ZoomExtents(ProjectionMatrix, ViewMatrix, CameraPosition);
+	lcMatrix44 ProjectionMatrix, ViewMatrix;
+
+	Info->ZoomExtents(20.0f, Aspect, ProjectionMatrix, ViewMatrix);
+
+	Context->SetProjectionMatrix(ProjectionMatrix);
 
 	lcScene Scene;
 	Scene.Begin(ViewMatrix);
@@ -360,11 +376,11 @@ void lcPartSelectionListModel::DrawPreview(int InfoIndex)
 
 	Scene.Draw(Context);
 
-	mParts[InfoIndex].second = QPixmap::fromImage(Context->GetRenderToTextureImage(Width, Height)).scaled(mIconSize, mIconSize, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+	mParts[InfoIndex].second = QPixmap::fromImage(Context->GetRenderFramebufferImage(mRenderFramebuffer)).scaled(mIconSize, mIconSize, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
 
 	Library->ReleasePieceInfo(Info);
 
-	Context->EndRenderToTexture();
+	Context->ClearFramebuffer();
 	Context->ClearResources();
 
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 2, 0))
@@ -374,6 +390,16 @@ void lcPartSelectionListModel::DrawPreview(int InfoIndex)
 #endif
 }
 
+void lcPartSelectionListModel::SetShowDecoratedParts(bool Show)
+{
+	if (Show == mShowDecoratedParts)
+		return;
+
+	mShowDecoratedParts = Show;
+
+	SetFilter(mFilter);
+}
+
 void lcPartSelectionListModel::SetIconSize(int Size)
 {
 	if (Size == mIconSize)
@@ -387,6 +413,8 @@ void lcPartSelectionListModel::SetIconSize(int Size)
 		mParts[PartIdx].second = QPixmap();
 
 	endResetModel();
+
+	SetFilter(mFilter);
 }
 
 void lcPartSelectionListModel::SetShowPartNames(bool Show)
@@ -398,6 +426,8 @@ void lcPartSelectionListModel::SetShowPartNames(bool Show)
 
 	beginResetModel();
 	endResetModel();
+
+	SetFilter(mFilter);
 }
 
 lcPartSelectionListView::lcPartSelectionListView(QWidget* Parent)
@@ -410,10 +440,8 @@ lcPartSelectionListView::lcPartSelectionListView(QWidget* Parent)
 	setContextMenuPolicy(Qt::CustomContextMenu);
 
 	mListModel = new lcPartSelectionListModel(this);
-	mFilterModel = new lcPartSelectionFilterModel(this);
-	mFilterModel->setSourceModel(mListModel);
-	setModel(mFilterModel);
-	lcPartSelectionItemDelegate* ItemDelegate = new lcPartSelectionItemDelegate(this, mListModel, mFilterModel);
+	setModel(mListModel);
+	lcPartSelectionItemDelegate* ItemDelegate = new lcPartSelectionItemDelegate(this, mListModel);
 	setItemDelegate(ItemDelegate);
 
 	connect(this, SIGNAL(customContextMenuRequested(QPoint)), SLOT(CustomContextMenuRequested(QPoint)));
@@ -466,7 +494,7 @@ void lcPartSelectionListView::CustomContextMenuRequested(QPoint Pos)
 
 	QAction* DecoratedParts = Menu->addAction(tr("Show Decorated Parts"), this, SLOT(ToggleDecoratedParts()));
 	DecoratedParts->setCheckable(true);
-	DecoratedParts->setChecked(mFilterModel->GetShowDecoratedParts());
+	DecoratedParts->setChecked(mListModel->GetShowDecoratedParts());
 
 	if (mListModel->GetIconSize() != 0)
 	{
@@ -516,8 +544,8 @@ void lcPartSelectionListView::TogglePartNames()
 
 void lcPartSelectionListView::ToggleDecoratedParts()
 {
-	bool Show = !mFilterModel->GetShowDecoratedParts();
-	mFilterModel->SetShowDecoratedParts(Show);
+	bool Show = !mListModel->GetShowDecoratedParts();
+	mListModel->SetShowDecoratedParts(Show);
 	lcSetProfileInt(LC_PROFILE_PARTS_LIST_DECORATED, Show);
 }
 
@@ -535,6 +563,7 @@ void lcPartSelectionListView::UpdateViewMode()
 {
 	setViewMode(mListModel->GetIconSize() && !mListModel->IsListMode() ? QListView::IconMode : QListView::ListMode);
 	setWordWrap(mListModel->IsListMode());
+	setDragEnabled(true);
 }
 
 void lcPartSelectionListView::SetIconSize(int Size)
@@ -556,7 +585,7 @@ void lcPartSelectionListView::startDrag(Qt::DropActions SupportedActions)
 
 	QByteArray ItemData;
 	QDataStream DataStream(&ItemData, QIODevice::WriteOnly);
-	DataStream << QString(Info->m_strName);
+	DataStream << QString(Info->mFileName);
 
 	QMimeData* MimeData = new QMimeData;
 	MimeData->setData("application/vnd.leocad-part", ItemData);
@@ -698,7 +727,7 @@ void lcPartSelectionWidget::FilterChanged(const QString& Text)
 			mFilterAction->setIcon(QIcon(":/resources/parts_cancel.png"));
 	}
 
-	mPartsWidget->GetFilterModel()->SetFilter(Text);
+	mPartsWidget->GetListModel()->SetFilter(Text);
 }
 
 void lcPartSelectionWidget::FilterTriggered()
@@ -720,7 +749,7 @@ void lcPartSelectionWidget::CategoryChanged(QTreeWidgetItem* Current, QTreeWidge
 	else
 		ListModel->SetCategory(mCategoriesWidget->indexOfTopLevelItem(Current) - 2);
 
-	mPartsWidget->setCurrentIndex(mPartsWidget->GetFilterModel()->index(0, 0));
+	mPartsWidget->setCurrentIndex(ListModel->index(0, 0));
 }
 
 void lcPartSelectionWidget::PartChanged(const QModelIndex& Current, const QModelIndex& Previous)
