@@ -57,7 +57,7 @@ lcProfileEntry gProfileEntries[LC_NUM_PROFILE_KEYS] =
 {
 	lcProfileEntry("Settings", "FixedAxes", false),                                  // LC_PROFILE_FIXED_AXES
 	lcProfileEntry("Settings", "LineWidth", 1.0f),                                   // LC_PROFILE_LINE_WIDTH
-	lcProfileEntry("Settings", "LightingMode", LC_LIGHTING_UNLIT),                   // LC_PROFILE_LIGHTING_MODE
+	lcProfileEntry("Settings", "ShadingMode", LC_SHADING_DEFAULT_LIGHTS),            // LC_PROFILE_SHADING_MODE
 	lcProfileEntry("Settings", "DrawAxes", 0),                                       // LC_PROFILE_DRAW_AXES
 	lcProfileEntry("Settings", "DrawEdgeLines", 1),                                  // LC_PROFILE_DRAW_EDGE_LINES
 	lcProfileEntry("Settings", "GridStuds", 1),                                      // LC_PROFILE_GRID_STUDS
@@ -109,9 +109,10 @@ lcProfileEntry gProfileEntries[LC_NUM_PROFILE_KEYS] =
 	lcProfileEntry("HTML", "PartsWidth", 128),                                       // LC_PROFILE_HTML_PARTS_WIDTH
 	lcProfileEntry("HTML", "PartsHeight", 128),                                      // LC_PROFILE_HTML_PARTS_HEIGHT
 
-	lcProfileEntry("POVRay", "Path", ""),                                            // LC_PROFILE_POVRAY_PATH
+	lcProfileEntry("POVRay", "Path", "/usr/bin/povray"),                             // LC_PROFILE_POVRAY_PATH
 	lcProfileEntry("POVRay", "LGEOPath", ""),                                        // LC_PROFILE_POVRAY_LGEO_PATH
-	lcProfileEntry("POVRay", "Render", 1),                                           // LC_PROFILE_POVRAY_RENDER
+	lcProfileEntry("POVRay", "Width", 1280),                                         // LC_PROFILE_POVRAY_WIDTH
+	lcProfileEntry("POVRay", "Height", 720)                                          // LC_PROFILE_POVRAY_HEIGHT
 };
 
 void lcRemoveProfileKey(LC_PROFILE_KEY Key)
