@@ -1,12 +1,11 @@
-#ifndef LC_PROFILE_H
-#define LC_PROFILE_H
+#pragma once
 
 enum LC_PROFILE_KEY
 {
 	// Settings.
 	LC_PROFILE_FIXED_AXES,
 	LC_PROFILE_LINE_WIDTH,
-	LC_PROFILE_LIGHTING_MODE,
+	LC_PROFILE_SHADING_MODE,
 	LC_PROFILE_DRAW_AXES,
 	LC_PROFILE_DRAW_EDGE_LINES,
 	LC_PROFILE_GRID_STUDS,
@@ -61,7 +60,8 @@ enum LC_PROFILE_KEY
 	LC_PROFILE_HTML_PARTS_HEIGHT,
 	LC_PROFILE_POVRAY_PATH,
 	LC_PROFILE_POVRAY_LGEO_PATH,
-	LC_PROFILE_POVRAY_RENDER,
+	LC_PROFILE_POVRAY_WIDTH,
+	LC_PROFILE_POVRAY_HEIGHT,
 
 	LC_NUM_PROFILE_KEYS
 };
@@ -118,4 +118,3 @@ void lcSetProfileString(LC_PROFILE_KEY Key, const QString& Value);
 void lcSetProfileStringList(LC_PROFILE_KEY Key, const QStringList& Value);
 void lcSetProfileBuffer(LC_PROFILE_KEY Key, const QByteArray& Buffer);
 
-#endif // LC_PROFILE_H
