@@ -27,7 +27,7 @@ lcTexture* lcLoadTexture(const QString& FileName, int Flags)
 
 void lcReleaseTexture(lcTexture* Texture)
 {
-	if (Texture && Texture->Release() == 0)
+	if (Texture && !Texture->Release())
 		delete Texture;
 }
 
@@ -46,12 +46,12 @@ lcTexture::~lcTexture()
 void lcTexture::CreateGridTexture()
 {
 	const int NumLevels = 9;
-	Image GridImages[NumLevels];
-	lcuint8* Previous = nullptr;
+	mImages.resize(NumLevels);
+	quint8* Previous = nullptr;
 
 	for (int ImageLevel = 0; ImageLevel < NumLevels; ImageLevel++)
 	{
-		Image& GridImage = GridImages[ImageLevel];
+		Image& GridImage = mImages[ImageLevel];
 		const int GridSize = 256 >> ImageLevel;
 		GridImage.Allocate(GridSize, GridSize, LC_PIXEL_FORMAT_A8);
 
@@ -63,24 +63,24 @@ void lcTexture::CreateGridTexture()
 			{
 				for (int x = 0; x < GridSize - 1; x++)
 				{
-					lcuint8 a = Previous[x * 2 + y * 2 * PreviousGridSize] > 64 ? 255 : 0;
-					lcuint8 b = Previous[x * 2 + 1 + y * 2 * PreviousGridSize] > 64 ? 255 : 0;
-					lcuint8 c = Previous[x * 2 + (y * 2 + 1) * PreviousGridSize] > 64 ? 255 : 0;
-					lcuint8 d = Previous[x * 2 + 1 + (y * 2 + 1) * PreviousGridSize] > 64 ? 255 : 0;
+					quint8 a = Previous[x * 2 + y * 2 * PreviousGridSize] > 64 ? 255 : 0;
+					quint8 b = Previous[x * 2 + 1 + y * 2 * PreviousGridSize] > 64 ? 255 : 0;
+					quint8 c = Previous[x * 2 + (y * 2 + 1) * PreviousGridSize] > 64 ? 255 : 0;
+					quint8 d = Previous[x * 2 + 1 + (y * 2 + 1) * PreviousGridSize] > 64 ? 255 : 0;
 					GridImage.mData[x + y * GridSize] = (a + b + c + d) / 4;
 				}
 
 				int x = GridSize - 1;
-				lcuint8 a = Previous[x * 2 + y * 2 * PreviousGridSize];
-				lcuint8 c = Previous[x * 2 + (y * 2 + 1) * PreviousGridSize];
+				quint8 a = Previous[x * 2 + y * 2 * PreviousGridSize];
+				quint8 c = Previous[x * 2 + (y * 2 + 1) * PreviousGridSize];
 				GridImage.mData[x + y * GridSize] = (a + c) / 2;
 			}
 
 			int y = GridSize - 1;
 			for (int x = 0; x < GridSize - 1; x++)
 			{
-				lcuint8 a = Previous[x * 2 + y * 2 * PreviousGridSize];
-				lcuint8 b = Previous[x * 2 + 1 + y * 2 * PreviousGridSize];
+				quint8 a = Previous[x * 2 + y * 2 * PreviousGridSize];
+				quint8 b = Previous[x * 2 + 1 + y * 2 * PreviousGridSize];
 				GridImage.mData[x + y * GridSize] = (a + b) / 2;
 			}
 
@@ -91,11 +91,11 @@ void lcTexture::CreateGridTexture()
 		{
 			const float Radius1 = (80 >> ImageLevel) * (80 >> ImageLevel);
 			const float Radius2 = (72 >> ImageLevel) * (72 >> ImageLevel);
-			lcuint8* TempBuffer = new lcuint8[GridSize * GridSize];
+			quint8* TempBuffer = new quint8[GridSize * GridSize];
 
 			for (int y = 0; y < GridSize; y++)
 			{
-				lcuint8* Pixel = TempBuffer + y * GridSize;
+				quint8* Pixel = TempBuffer + y * GridSize;
 				memset(Pixel, 0, GridSize);
 
 				const float y2 = (y - GridSize / 2) * (y - GridSize / 2);
@@ -127,24 +127,24 @@ void lcTexture::CreateGridTexture()
 			{
 				for (int x = 0; x < GridSize - 1; x++)
 				{
-					lcuint8 a = TempBuffer[x + y * GridSize];
-					lcuint8 b = TempBuffer[x + 1 + y * GridSize];
-					lcuint8 c = TempBuffer[x + (y + 1) * GridSize];
-					lcuint8 d = TempBuffer[x + 1 + (y + 1) * GridSize];
+					quint8 a = TempBuffer[x + y * GridSize];
+					quint8 b = TempBuffer[x + 1 + y * GridSize];
+					quint8 c = TempBuffer[x + (y + 1) * GridSize];
+					quint8 d = TempBuffer[x + 1 + (y + 1) * GridSize];
 					GridImage.mData[x + y * GridSize] = (a + b + c + d) / 4;
 				}
 
 				int x = GridSize - 1;
-				lcuint8 a = TempBuffer[x + y * GridSize];
-				lcuint8 c = TempBuffer[x + (y + 1) * GridSize];
+				quint8 a = TempBuffer[x + y * GridSize];
+				quint8 c = TempBuffer[x + (y + 1) * GridSize];
 				GridImage.mData[x + y * GridSize] = (a + c) / 2;
 			}
 
 			int y = GridSize - 1;
 			for (int x = 0; x < GridSize - 1; x++)
 			{
-				lcuint8 a = TempBuffer[x + y * GridSize];
-				lcuint8 b = TempBuffer[x + 1 + y * GridSize];
+				quint8 a = TempBuffer[x + y * GridSize];
+				quint8 b = TempBuffer[x + 1 + y * GridSize];
 				GridImage.mData[x + y * GridSize] = (a + b) / 2;
 			}
 
@@ -156,9 +156,10 @@ void lcTexture::CreateGridTexture()
 		Previous = GridImage.mData;
 	}
 
-	Load(GridImages, NumLevels, LC_TEXTURE_WRAPU | LC_TEXTURE_WRAPV | LC_TEXTURE_MIPMAPS | LC_TEXTURE_ANISOTROPIC);
+	mRefCount = 1;
+	mFlags = LC_TEXTURE_WRAPU | LC_TEXTURE_WRAPV | LC_TEXTURE_MIPMAPS | LC_TEXTURE_ANISOTROPIC;
 
-    mRefCount = 1;
+	lcGetPiecesLibrary()->QueueTextureUpload(this);
 }
 
 bool lcTexture::Load()
@@ -168,28 +169,28 @@ bool lcTexture::Load()
 
 bool lcTexture::Load(const QString& FileName, int Flags)
 {
-	Image image;
+	mImages.resize(1);
 
-	if (!image.FileLoad(FileName))
+	if (!mImages[0].FileLoad(FileName))
 		return false;
 
-	return Load(image, Flags);
+	return Load(Flags);
 }
 
 bool lcTexture::Load(lcMemFile& File, int Flags)
 {
-	Image image;
+	mImages.resize(1);
 
-	if (!image.FileLoad(File))
+	if (!mImages[0].FileLoad(File))
 		return false;
 
-	return Load(image, Flags);
+	return Load(Flags);
 }
 
-bool lcTexture::Load(Image* images, int NumLevels, int Flags) // todo: this should be part of lcContext, it can be called from multiple threads 
+void lcTexture::Upload()
 {
-	mWidth = images[0].mWidth;
-	mHeight = images[0].mHeight;
+	mWidth = mImages[0].mWidth;
+	mHeight = mImages[0].mHeight;
 
 	glGenTextures(1, &mTexture);
 
@@ -199,13 +200,13 @@ bool lcTexture::Load(Image* images, int NumLevels, int Flags) // todo: this shou
 		{ GL_NEAREST, GL_LINEAR, GL_LINEAR, GL_LINEAR, GL_LINEAR  },
 	};
 
-	int FilterFlags = Flags & LC_TEXTURE_FILTER_MASK;
+	int FilterFlags = mFlags & LC_TEXTURE_FILTER_MASK;
 	int FilterIndex = FilterFlags >> LC_TEXTURE_FILTER_SHIFT;
-	int MipIndex = Flags & LC_TEXTURE_MIPMAPS ? 0 : 1;
+	int MipIndex = mFlags & LC_TEXTURE_MIPMAPS ? 0 : 1;
 
 	glBindTexture(GL_TEXTURE_2D, mTexture);
-	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, (Flags & LC_TEXTURE_WRAPU) ? GL_REPEAT : GL_CLAMP_TO_EDGE);
-	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, (Flags & LC_TEXTURE_WRAPV) ? GL_REPEAT : GL_CLAMP_TO_EDGE);
+	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, (mFlags & LC_TEXTURE_WRAPU) ? GL_REPEAT : GL_CLAMP_TO_EDGE);
+	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, (mFlags & LC_TEXTURE_WRAPV) ? GL_REPEAT : GL_CLAMP_TO_EDGE);
 	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, Filters[MipIndex][FilterIndex]);
 	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, Filters[1][FilterIndex]);
 	glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
@@ -214,7 +215,7 @@ bool lcTexture::Load(Image* images, int NumLevels, int Flags) // todo: this shou
 		glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAX_ANISOTROPY_EXT, lcMin(4.0f, gMaxAnisotropy));
 
 	int Format;
-	switch (images[0].mFormat)
+	switch (mImages[0].mFormat)
 	{
     default:
     case LC_PIXEL_FORMAT_INVALID:
@@ -234,14 +235,15 @@ bool lcTexture::Load(Image* images, int NumLevels, int Flags) // todo: this shou
 		break;
 	}
 
-	void* Data = images[0].mData;
+	void* Data = mImages[0].mData;
 	glTexImage2D(GL_TEXTURE_2D, 0, Format, mWidth, mHeight, 0, Format, GL_UNSIGNED_BYTE, Data);
+	int MaxLevel = 0;
 
-	if (Flags & LC_TEXTURE_MIPMAPS)
+	if (mFlags & LC_TEXTURE_MIPMAPS)
 	{
 		int Width = mWidth;
 		int Height = mHeight;
-		int Components = images[0].GetBPP();
+		int Components = mImages[0].GetBPP();
 
 		for (int Level = 1; ((Width != 1) || (Height != 1)); Level++)
 		{
@@ -250,7 +252,7 @@ bool lcTexture::Load(Image* images, int NumLevels, int Flags) // todo: this shou
 			Width = lcMax(1, Width >> 1);
 			Height = lcMax(1, Height >> 1);
 
-			if (NumLevels == 1)
+			if (mImages.size() == 1)
 			{
 				GLubyte *Out, *In;
 
@@ -262,22 +264,25 @@ bool lcTexture::Load(Image* images, int NumLevels, int Flags) // todo: this shou
 							Out[c] = (In[c] + In[c + Components] + In[RowStride] + In[c + RowStride + Components]) / 4;
 			}
 			else
-				Data = images[Level].mData;
+				Data = mImages[Level].mData;
 
 			glTexImage2D(GL_TEXTURE_2D, Level, Format, Width, Height, 0, Format, GL_UNSIGNED_BYTE, Data);
+			MaxLevel++;
 		}
 	}
 
+	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAX_LEVEL, MaxLevel);
 	glBindTexture(GL_TEXTURE_2D, 0);
-
-	return true;
 }
 
-bool lcTexture::Load(Image& image, int Flags)
+bool lcTexture::Load(int Flags)
 {
-	image.ResizePow2();
+	for (Image& Image : mImages)
+		Image.ResizePow2();
+	mFlags = Flags;
 
-	return Load(&image, 1, Flags);
+	lcGetPiecesLibrary()->QueueTextureUpload(this);
+	return true;
 }
 
 void lcTexture::Unload()
