@@ -21,7 +21,7 @@ lcPiece::lcPiece(PieceInfo* Info)
 	: lcObject(LC_OBJECT_PIECE)
 {
 	mMesh = nullptr;
-	SetPieceInfo(Info, true);
+	SetPieceInfo(Info, QString(), true);
 	mState = 0;
 	mColorIndex = gDefaultColor;
 	mColorCode = 16;
@@ -39,7 +39,7 @@ lcPiece::lcPiece(const lcPiece& Other)
 	: lcObject(LC_OBJECT_PIECE)
 {
 	mMesh = nullptr;
-	SetPieceInfo(Other.mPieceInfo, true);
+	SetPieceInfo(Other.mPieceInfo, Other.mID, true);
 	mState = 0;
 	mColorIndex = Other.mColorIndex;
 	mColorCode = Other.mColorCode;
@@ -67,7 +67,7 @@ lcPiece::~lcPiece()
 	delete mMesh;
 }
 
-void lcPiece::SetPieceInfo(PieceInfo* Info, bool Wait)
+void lcPiece::SetPieceInfo(PieceInfo* Info, const QString& ID, bool Wait)
 {
 	lcPiecesLibrary* Library = lcGetPiecesLibrary();
 
@@ -75,6 +75,13 @@ void lcPiece::SetPieceInfo(PieceInfo* Info, bool Wait)
 	if (mPieceInfo)
 		Library->LoadPieceInfo(mPieceInfo, Wait, true);
 
+	if (!ID.isEmpty())
+		mID = ID;
+	else if (mPieceInfo)
+		mID = mPieceInfo->mFileName;
+	else
+		mID.clear();
+
 	mControlPoints.RemoveAll();
 	delete mMesh;
 	mMesh = nullptr;
@@ -88,6 +95,11 @@ void lcPiece::SetPieceInfo(PieceInfo* Info, bool Wait)
 	}
 }
 
+void lcPiece::UpdateID()
+{
+	mID = mPieceInfo->mFileName;
+}
+
 void lcPiece::SaveLDraw(QTextStream& Stream) const
 {
 	QLatin1String LineEnding("\r\n");
@@ -106,7 +118,7 @@ void lcPiece::SaveLDraw(QTextStream& Stream) const
 		Stream << QLatin1String("0 !LEOCAD PIECE PIVOT ");
 
 		for (int NumberIdx = 0; NumberIdx < 12; NumberIdx++)
-			Stream << ' ' << lcFormatValue(PivotNumbers[NumberIdx]);
+			Stream << ' ' << lcFormatValue(PivotNumbers[NumberIdx], NumberIdx < 3 ? 4 : 6);
 
 		Stream << LineEnding;
 	}
@@ -123,9 +135,9 @@ void lcPiece::SaveLDraw(QTextStream& Stream) const
 	float Numbers[12] = { Matrix[12], -Matrix[14], Matrix[13], Matrix[0], -Matrix[8], Matrix[4], -Matrix[2], Matrix[10], -Matrix[6], Matrix[1], -Matrix[9], Matrix[5] };
 
 	for (int NumberIdx = 0; NumberIdx < 12; NumberIdx++)
-		Stream << lcFormatValue(Numbers[NumberIdx]) << ' ';
+		Stream << lcFormatValue(Numbers[NumberIdx], NumberIdx < 3 ? 4 : 6) << ' ';
 
-	Stream << mPieceInfo->GetSaveID() << LineEnding;
+	Stream << mID << LineEnding;
 }
 
 bool lcPiece::ParseLDrawLine(QTextStream& Stream)
@@ -162,7 +174,7 @@ bool lcPiece::ParseLDrawLine(QTextStream& Stream)
 
 bool lcPiece::FileLoad(lcFile& file)
 {
-	lcuint8 version, ch;
+	quint8 version, ch;
 
 	version = file.ReadU8();
 
@@ -174,10 +186,10 @@ bool lcPiece::FileLoad(lcFile& file)
 		if (file.ReadU8() != 1)
 			return false;
 
-		lcuint16 time;
+		quint16 time;
 		float param[4];
-		lcuint8 type;
-		lcuint32 n;
+		quint8 type;
+		quint32 n;
 
 		file.ReadU32(&n, 1);
 		while (n--)
@@ -203,12 +215,12 @@ bool lcPiece::FileLoad(lcFile& file)
 
   if (version < 9)
   {
-    lcuint16 time;
-    lcuint8 type;
+    quint16 time;
+    quint8 type;
 
     if (version > 5)
     {
-      lcuint32 keys;
+      quint32 keys;
       float param[4];
 
       file.ReadU32(&keys, 1);
@@ -256,14 +268,14 @@ bool lcPiece::FileLoad(lcFile& file)
 				ModelWorld = lcMul(lcMatrix44RotationZ(Rotation[2] * LC_DTOR), lcMul(lcMatrix44RotationY(Rotation[1] * LC_DTOR), lcMul(lcMatrix44RotationX(Rotation[0] * LC_DTOR), ModelWorld)));
 			}
 
-			lcuint8 b;
+			quint8 b;
 			file.ReadU8(&b, 1);
 			time = b;
 
 			ChangeKey(mPositionKeys, ModelWorld.GetTranslation(), 1, true);
 			ChangeKey(mRotationKeys, lcMatrix33(ModelWorld), time, true);
 
-			lcint32 bl;
+			qint32 bl;
 			file.ReadS32(&bl, 1);
         }
       }
@@ -291,14 +303,15 @@ bool lcPiece::FileLoad(lcFile& file)
   }
   else
 	  file.ReadBuffer(name, LC_PIECE_NAME_LEN);
+  strcat(name, ".dat");
 
 	PieceInfo* pInfo = lcGetPiecesLibrary()->FindPiece(name, nullptr, true, false);
-	SetPieceInfo(pInfo, true);
+	SetPieceInfo(pInfo, QString(), true);
 
 	// 11 (0.77)
 	if (version < 11)
 	{
-		lcuint8 Color;
+		quint8 Color;
 
 		file.ReadU8(&Color, 1);
 
@@ -311,7 +324,7 @@ bool lcPiece::FileLoad(lcFile& file)
 		file.ReadU32(&mColorCode, 1);
 	mColorIndex = lcGetColorIndex(mColorCode);
 
-  lcuint8 Step;
+  quint8 Step;
   file.ReadU8(&Step, 1);
   mStepShow = Step;
   if (version > 1)
@@ -329,7 +342,7 @@ bool lcPiece::FileLoad(lcFile& file)
 
     if (version > 7)
     {
-      lcuint8 Hidden;
+      quint8 Hidden;
       file.ReadU8(&Hidden, 1);
 	  if (Hidden & 1)
 		  mState |= LC_PIECE_HIDDEN;
@@ -338,7 +351,7 @@ bool lcPiece::FileLoad(lcFile& file)
     }
     else
     {
-      lcint32 hide;
+      qint32 hide;
       file.ReadS32(&hide, 1);
       if (hide != 0)
         mState |= LC_PIECE_HIDDEN;
@@ -346,7 +359,7 @@ bool lcPiece::FileLoad(lcFile& file)
     }
 
     // 7 (0.64)
-    lcint32 i = -1;
+    qint32 i = -1;
     if (version > 6)
       file.ReadS32(&i, 1);
     mGroup = (lcGroup*)(quintptr)i;
@@ -662,9 +675,9 @@ void lcPiece::SubModelAddRenderMeshes(lcScene& Scene, const lcMatrix44& WorldMat
 		Scene.AddMesh(mMesh, lcMul(mModelWorld, WorldMatrix), ColorIndex, Focused ? LC_RENDERMESH_FOCUSED : (Selected ? LC_RENDERMESH_SELECTED : LC_RENDERMESH_NONE), mPieceInfo->mFlags);
 }
 
-void lcPiece::Move(lcStep Step, bool AddKey, const lcVector3& Distance)
+void lcPiece::MoveSelected(lcStep Step, bool AddKey, const lcVector3& Distance)
 {
-	lcuint32 Section = GetFocusSection();
+	quint32 Section = GetFocusSection();
 
 	if (Section == LC_PIECE_SECTION_POSITION || Section == LC_PIECE_SECTION_INVALID)
 	{
@@ -692,7 +705,7 @@ void lcPiece::Move(lcStep Step, bool AddKey, const lcVector3& Distance)
 
 void lcPiece::Rotate(lcStep Step, bool AddKey, const lcMatrix33& RotationMatrix, const lcVector3& Center, const lcMatrix33& RotationFrame)
 {
-	lcuint32 Section = GetFocusSection();
+	quint32 Section = GetFocusSection();
 
 	if (Section == LC_PIECE_SECTION_POSITION || Section == LC_PIECE_SECTION_INVALID)
 	{
@@ -754,9 +767,9 @@ void lcPiece::RotatePivotPoint(const lcMatrix33& RotationMatrix)
 	mState |= LC_PIECE_PIVOT_POINT_VALID;
 }
 
-lcuint32 lcPiece::GetAllowedTransforms() const
+quint32 lcPiece::GetAllowedTransforms() const
 {
-	lcuint32 Section = GetFocusSection();
+	quint32 Section = GetFocusSection();
 
 	if (Section == LC_PIECE_SECTION_POSITION || Section == LC_PIECE_SECTION_INVALID)
 		return LC_OBJECT_TRANSFORM_MOVE_X | LC_OBJECT_TRANSFORM_MOVE_Y | LC_OBJECT_TRANSFORM_MOVE_Z | LC_OBJECT_TRANSFORM_ROTATE_X | LC_OBJECT_TRANSFORM_ROTATE_Y | LC_OBJECT_TRANSFORM_ROTATE_Z;
@@ -819,7 +832,7 @@ bool lcPiece::IsVisible(lcStep Step)
 	if (mState & LC_PIECE_HIDDEN)
 		return false;
 
-	return (mStepShow <= Step) && (mStepHide > Step);
+	return (mStepShow <= Step) && (mStepHide > Step || mStepHide == LC_STEP_MAX);
 }
 
 const lcBoundingBox& lcPiece::GetBoundingBox() const
