@@ -1,5 +1,4 @@
-#ifndef _PIECE_H_
-#define _PIECE_H_
+#pragma once
 
 class PieceInfo;
 
@@ -64,7 +63,7 @@ public:
 		return (mState & LC_PIECE_SELECTION_MASK) != 0;
 	}
 
-	virtual bool IsSelected(lcuint32 Section) const override
+	virtual bool IsSelected(quint32 Section) const override
 	{
 		Q_UNUSED(Section);
 
@@ -79,7 +78,7 @@ public:
 			mState &= ~(LC_PIECE_SELECTION_MASK | LC_PIECE_FOCUS_MASK);
 	}
 
-	virtual void SetSelected(lcuint32 Section, bool Selected) override
+	virtual void SetSelected(quint32 Section, bool Selected) override
 	{
 		switch (Section)
 		{
@@ -153,7 +152,7 @@ public:
 		return (mState & LC_PIECE_FOCUS_MASK) != 0;
 	}
 
-	virtual bool IsFocused(lcuint32 Section) const override
+	virtual bool IsFocused(quint32 Section) const override
 	{
 		switch (Section)
 		{
@@ -188,7 +187,7 @@ public:
 		return false;
 	}
 
-	virtual void SetFocused(lcuint32 Section, bool Focused) override
+	virtual void SetFocused(quint32 Section, bool Focused) override
 	{
 		switch (Section)
 		{
@@ -257,7 +256,7 @@ public:
 		}
 	}
 
-	virtual lcuint32 GetFocusSection() const override
+	virtual quint32 GetFocusSection() const override
 	{
 		if (mState & LC_PIECE_POSITION_FOCUSED)
 			return LC_PIECE_SECTION_POSITION;
@@ -289,9 +288,9 @@ public:
 		return LC_PIECE_SECTION_INVALID;
 	}
 
-	virtual lcuint32 GetAllowedTransforms() const override;
+	virtual quint32 GetAllowedTransforms() const override;
 
-	virtual lcVector3 GetSectionPosition(lcuint32 Section) const override
+	virtual lcVector3 GetSectionPosition(quint32 Section) const override
 	{
 		switch (Section)
 		{
@@ -385,16 +384,23 @@ public:
 		UpdateMesh();
 	}
 
+	const QString& GetID() const
+	{
+		return mID;
+	}
+
+	void UpdateID();
+
 	const char* GetName() const override;
 	bool IsVisible(lcStep Step);
 	void Initialize(const lcMatrix44& WorldMatrix, lcStep Step);
 	const lcBoundingBox& GetBoundingBox() const;
 	void CompareBoundingBox(lcVector3& Min, lcVector3& Max) const;
-	void SetPieceInfo(PieceInfo* Info, bool Wait);
+	void SetPieceInfo(PieceInfo* Info, const QString& ID, bool Wait);
 	bool FileLoad(lcFile& file);
 
 	void UpdatePosition(lcStep Step);
-	void Move(lcStep Step, bool AddKey, const lcVector3& Distance);
+	void MoveSelected(lcStep Step, bool AddKey, const lcVector3& Distance);
 	void Rotate(lcStep Step, bool AddKey, const lcMatrix33& RotationMatrix, const lcVector3& Center, const lcMatrix33& RotationFrame);
 	void MovePivotPoint(const lcVector3& Distance);
 	void RotatePivotPoint(const lcMatrix33& RotationMatrix);
@@ -450,7 +456,7 @@ public:
 			mStepHide = mStepShow + 1;
 	}
 
-	void SetColorCode(lcuint32 ColorCode)
+	void SetColorCode(quint32 ColorCode)
 	{
 		mColorCode = ColorCode;
 		mColorIndex = lcGetColorIndex(ColorCode);
@@ -474,7 +480,7 @@ public:
 
 	lcVector3 GetRotationCenter() const
 	{
-		lcuint32 Section = GetFocusSection();
+		quint32 Section = GetFocusSection();
 
 		if (Section == LC_PIECE_SECTION_POSITION || Section == LC_PIECE_SECTION_INVALID)
 		{
@@ -499,7 +505,7 @@ public:
 
 	lcMatrix33 GetRelativeRotation() const
 	{
-		lcuint32 Section = GetFocusSection();
+		quint32 Section = GetFocusSection();
 
 		if (Section == LC_PIECE_SECTION_POSITION || Section == LC_PIECE_SECTION_INVALID)
 		{
@@ -531,7 +537,7 @@ public:
 	PieceInfo* mPieceInfo;
 
 	int mColorIndex;
-	lcuint32 mColorCode;
+	quint32 mColorCode;
 
 	lcMatrix44 mModelWorld;
 	lcMatrix44 mPivotMatrix;
@@ -553,15 +559,14 @@ protected:
 	lcArray<lcObjectKey<lcMatrix33>> mRotationKeys;
 
 	int mFileLine;
+	QString mID;
 
 	lcGroup* mGroup;
 
 	lcStep mStepShow;
 	lcStep mStepHide;
 
-	lcuint32 mState;
+	quint32 mState;
 	lcArray<lcPieceControlPoint> mControlPoints;
 	lcMesh* mMesh;
 };
-
-#endif // _PIECE_H_
