@@ -34,14 +34,6 @@ PieceInfo::~PieceInfo()
 		Unload();
 }
 
-QString PieceInfo::GetSaveID() const
-{
-	if (mFlags & (LC_PIECE_MODEL | LC_PIECE_PROJECT))
-		return QString::fromLatin1(m_strName);
-
-	return QString::fromLatin1(m_strName) + QLatin1String(".DAT");
-}
-
 void PieceInfo::SetMesh(lcMesh* Mesh)
 {
 	mBoundingBox = Mesh->mBoundingBox;
@@ -68,8 +60,8 @@ void PieceInfo::SetModel(lcModel* Model, bool UpdateMesh, Project* CurrentProjec
 		mModel = Model;
 	}
 
-	strncpy(m_strName, Model->GetProperties().mName.toUpper().toLatin1().data(), sizeof(m_strName));
-	m_strName[sizeof(m_strName)-1] = 0;
+	strncpy(mFileName, Model->GetProperties().mName.toLatin1().data(), sizeof(mFileName));
+	mFileName[sizeof(mFileName)-1] = 0;
 	strncpy(m_strDescription, Model->GetProperties().mName.toLatin1().data(), sizeof(m_strDescription));
 	m_strDescription[sizeof(m_strDescription)-1] = 0;
 
@@ -97,7 +89,7 @@ void PieceInfo::SetModel(lcModel* Model, bool UpdateMesh, Project* CurrentProjec
 	}
 }
 
-void PieceInfo::SetProject(Project* Project, const char* PieceName)
+void PieceInfo::CreateProject(Project* Project, const char* PieceName)
 {
 	if (mProject != Project)
 	{
@@ -106,10 +98,10 @@ void PieceInfo::SetProject(Project* Project, const char* PieceName)
 		mState = LC_PIECEINFO_LOADED;
 	}
 
-	strncpy(m_strName, PieceName, sizeof(m_strName));
-	m_strName[sizeof(m_strName)-1] = 0;
+	strncpy(mFileName, PieceName, sizeof(mFileName));
+	mFileName[sizeof(mFileName) - 1] = 0;
 	strncpy(m_strDescription, Project->GetFileName().toLatin1().data(), sizeof(m_strDescription));
-	m_strDescription[sizeof(m_strDescription)-1] = 0;
+	m_strDescription[sizeof(m_strDescription) - 1] = 0;
 }
 
 bool PieceInfo::IncludesModel(const lcModel* Model) const
@@ -127,10 +119,10 @@ bool PieceInfo::IncludesModel(const lcModel* Model) const
 
 void PieceInfo::CreatePlaceholder(const char* Name)
 {
-	strncpy(m_strName, Name, sizeof(m_strName));
-	m_strName[sizeof(m_strName)-1] = 0;
+	strncpy(mFileName, Name, sizeof(mFileName));
+	mFileName[sizeof(mFileName) - 1] = 0;
 	strncpy(m_strDescription, Name, sizeof(m_strDescription));
-	m_strDescription[sizeof(m_strDescription)-1] = 0;
+	m_strDescription[sizeof(m_strDescription) - 1] = 0;
 
 	SetPlaceholder();
 }
@@ -284,31 +276,20 @@ bool PieceInfo::BoxTest(const lcMatrix44& WorldMatrix, const lcVector4 WorldPlan
 	return false;
 }
 
-// Zoom extents for the preview window and print catalog
-void PieceInfo::ZoomExtents(const lcMatrix44& ProjectionMatrix, lcMatrix44& ViewMatrix, float* EyePos) const
+void PieceInfo::ZoomExtents(float FoV, float AspectRatio, lcMatrix44& ProjectionMatrix, lcMatrix44& ViewMatrix) const
 {
 	lcVector3 Points[8];
 	lcGetBoxCorners(mBoundingBox, Points);
 
 	lcVector3 Center = (mBoundingBox.Min + mBoundingBox.Max) / 2.0f;
-	lcVector3 Position;
-
-	if (EyePos)
-		Position = lcVector3(EyePos[0], EyePos[1], EyePos[2]);
-	else
-		Position = lcVector3(-250.0f, -250.0f, 75.0f);
-	Position += Center;
+	lcVector3 Position = Center + lcVector3(100.0f, -100.0f, 75.0f);
 
+	ProjectionMatrix = lcMatrix44Perspective(FoV, AspectRatio, 1.0f, 12500.0f);
 	lcMatrix44 ModelView = lcMatrix44LookAt(Position, Center, lcVector3(0, 0, 1));
-	Position = lcZoomExtents(Position, ModelView, ProjectionMatrix, Points, 8);
+	float FarDistance;
+	std::tie(Position, FarDistance) = lcZoomExtents(Position, ModelView, ProjectionMatrix, Points, 8);
 	ViewMatrix = lcMatrix44LookAt(Position, Center, lcVector3(0, 0, 1));
-
-	if (EyePos)
-	{
-		EyePos[0] = Position[0];
-		EyePos[1] = Position[1];
-		EyePos[2] = Position[2];
-	}
+	ProjectionMatrix = lcMatrix44Perspective(FoV, AspectRatio, 1.0f, FarDistance);
 }
 
 void PieceInfo::AddRenderMesh(lcScene& Scene)
@@ -332,15 +313,15 @@ void PieceInfo::AddRenderMeshes(lcScene& Scene, const lcMatrix44& WorldMatrix, i
 	}
 }
 
-void PieceInfo::GetPartsList(int DefaultColorIndex, lcPartsList& PartsList) const
+void PieceInfo::GetPartsList(int DefaultColorIndex, bool IncludeSubmodels, lcPartsList& PartsList) const
 {
-	if (mFlags & LC_PIECE_MODEL)
-		mModel->GetPartsList(DefaultColorIndex, PartsList);
+	if (mFlags & LC_PIECE_MODEL && IncludeSubmodels)
+		mModel->GetPartsList(DefaultColorIndex, IncludeSubmodels, PartsList);
 	else if (mFlags & LC_PIECE_PROJECT)
 	{
 		lcModel* Model = mProject->GetMainModel();
 		if (Model)
-			Model->GetPartsList(DefaultColorIndex, PartsList);
+			Model->GetPartsList(DefaultColorIndex, IncludeSubmodels, PartsList);
 	}
 	else if (DefaultColorIndex < gNumUserColors)
 		PartsList[this][DefaultColorIndex]++;
