@@ -1,5 +1,4 @@
-#ifndef _PIECEINF_H_
-#define _PIECEINF_H_
+#pragma once
 
 #include <stdio.h>
 #include "lc_math.h"
@@ -31,8 +30,6 @@ public:
 	PieceInfo();
 	~PieceInfo();
 
-	QString GetSaveID() const;
-
 	const lcBoundingBox& GetBoundingBox() const
 	{
 		return mBoundingBox;
@@ -64,6 +61,11 @@ public:
 		return mModel;
 	}
 
+	Project* GetProject() const
+	{
+		return mProject;
+	}
+
 	void SetMesh(lcMesh* Mesh);
 
 	int AddRef()
@@ -111,7 +113,7 @@ public:
 
 	bool IsPatterned() const
 	{
-		const char* Name = m_strName;
+		const char* Name = mFileName;
 
 		while (*Name)
 		{
@@ -121,7 +123,7 @@ public:
 			Name++;
 		}
 
-		if (*Name == 'P')
+		if (*Name == 'P' || *Name == 'p')
 			return true;
 
 		return false;
@@ -132,7 +134,7 @@ public:
 		return (m_strDescription[0] == '~');
 	}
 
-	void ZoomExtents(const lcMatrix44& ProjectionMatrix, lcMatrix44& ViewMatrix, float* EyePos = nullptr) const;
+	void ZoomExtents(float FoV, float AspectRatio, lcMatrix44& ProjectionMatrix, lcMatrix44& ViewMatrix) const;
 	void AddRenderMesh(lcScene& Scene);
 	void AddRenderMeshes(lcScene& Scene, const lcMatrix44& WorldMatrix, int ColorIndex, bool Focused, bool Selected, bool Highlight) const;
 
@@ -140,11 +142,11 @@ public:
 
 	void SetPlaceholder();
 	void SetModel(lcModel* Model, bool UpdateMesh, Project* CurrentProject, bool SearchProjectFolder);
-	void SetProject(Project* Project, const char* PieceName);
+	void CreateProject(Project* Project, const char* PieceName);
 	bool IncludesModel(const lcModel* Model) const;
 	bool MinIntersectDist(const lcVector3& Start, const lcVector3& End, float& MinDistance) const;
 	bool BoxTest(const lcMatrix44& WorldMatrix, const lcVector4 Planes[6]) const;
-	void GetPartsList(int DefaultColorIndex, lcPartsList& PartsList) const;
+	void GetPartsList(int DefaultColorIndex, bool IncludeSubmodels, lcPartsList& PartsList) const;
 	void GetModelParts(const lcMatrix44& WorldMatrix, int DefaultColorIndex, lcArray<lcModelPartsEntry>& ModelParts) const;
 	void UpdateBoundingBox(lcArray<lcModel*>& UpdatedModels);
 
@@ -152,12 +154,14 @@ public:
 	void Unload();
 
 public:
-	char m_strName[LC_PIECE_NAME_LEN];
+	char mFileName[LC_PIECE_NAME_LEN];
 	char m_strDescription[128];
 	int mZipFileType;
 	int mZipFileIndex;
-	lcuint32 mFlags;
+	quint32 mFlags;
 	lcPieceInfoState mState;
+	int mFolderType;
+	int mFolderIndex;
 
 protected:
 	void ReleaseMesh();
@@ -170,4 +174,3 @@ protected:
 	lcSynthInfo* mSynthInfo;
 };
 
-#endif // _PIECEINF_H_
