@@ -1,5 +1,4 @@
-#ifndef _PROJECT_H_
-#define _PROJECT_H_
+#pragma once
 
 #include "object.h"
 #include "lc_array.h"
@@ -18,6 +17,29 @@
 #define LC_HTML_SUBMODELS     0x40
 #define LC_HTML_CURRENT_ONLY  0x80
 
+class lcHTMLExportOptions
+{
+public:
+	lcHTMLExportOptions(const Project* Project);
+	void SaveDefaults();
+
+	QString PathName;
+	bool TransparentImages;
+	bool SubModels;
+	bool CurrentOnly;
+	bool SinglePage;
+	bool IndexPage;
+	int StepImagesWidth;
+	int StepImagesHeight;
+	bool HighlightNewParts;
+	bool PartsListStep;
+	bool PartsListEnd;
+	bool PartsListImages;
+	int PartImagesColor;
+	int PartImagesWidth;
+	int PartImagesHeight;
+};
+
 enum LC_MOUSE_TRACK
 {
 	LC_TRACK_NONE,
@@ -36,11 +58,18 @@ public:
 		return mModels;
 	}
 
+	lcModel* GetModel(const QString& Name) const;
+
 	lcModel* GetActiveModel() const
 	{
 		return mActiveModel;
 	}
 
+	int GetActiveModelIndex() const
+	{
+		return mModels.FindIndex(mActiveModel);
+	}
+
 	lcModel* GetMainModel() const
 	{
 		return !mModels.IsEmpty() ? mModels[0] : nullptr;
@@ -54,6 +83,8 @@ public:
 		return mFileName;
 	}
 
+	QString GetImageFileName() const;
+
 	void SetActiveModel(int ModelIndex);
 	void SetActiveModel(const QString& ModelName);
 
@@ -66,13 +97,16 @@ public:
 	bool Save(QTextStream& Stream);
 	void Merge(Project* Other);
 	bool ImportLDD(const QString& FileName);
+	bool ImportInventory(const QByteArray& Inventory, const QString& Name, const QString& Description);
 
 	void SaveImage();
+	bool ExportModel(const QString& FileName, lcModel* Model);
 	void Export3DStudio(const QString& FileName);
 	void ExportBrickLink();
+	void ExportCOLLADA(const QString& FileName);
 	void ExportCSV();
-	void ExportHTML();
-	void ExportPOVRay();
+	void ExportHTML(const lcHTMLExportOptions& Options);
+	bool ExportPOVRay(const QString& FileName);
 	void ExportWavefront(const QString& FileName);
 
 	void UpdatePieceInfo(PieceInfo* Info) const;
@@ -82,9 +116,11 @@ protected:
 	void GetModelParts(lcArray<lcModelPartsEntry>& ModelParts);
 	QImage CreatePartsListImage(lcModel* Model, lcStep Step);
 	void CreateHTMLPieceList(QTextStream& Stream, lcModel* Model, lcStep Step, bool Images);
+	void SetFileName(const QString& FileName);
 
 	bool mModified;
 	QString mFileName;
+	QFileSystemWatcher mFileWatcher;
 
 	lcArray<lcModel*> mModels;
 	lcModel* mActiveModel;
@@ -98,4 +134,3 @@ inline lcModel* lcGetActiveModel()
 	return Project ? Project->GetActiveModel() : nullptr;
 }
 
-#endif // _PROJECT_H_
