@@ -3,7 +3,6 @@
 #include "lc_mainwindow.h"
 #include "camera.h"
 #include "view.h"
-#include "tr.h"
 #include "texfont.h"
 #include "lc_texture.h"
 #include "piece.h"
@@ -278,6 +277,16 @@ void View::SetViewpoint(lcViewpoint Viewpoint)
 	Redraw();
 }
 
+void View::SetCameraAngles(float Latitude, float Longitude)
+{
+	if (!mCamera || !mCamera->IsSimple())
+		mCamera = new lcCamera(true);
+
+	mCamera->SetAngles(Latitude, Longitude);
+	ZoomExtents();
+	Redraw();
+}
+
 void View::SetDefaultCamera()
 {
 	if (!mCamera || !mCamera->IsSimple())
@@ -290,9 +299,6 @@ lcMatrix44 View::GetProjectionMatrix() const
 {
 	float AspectRatio = (float)mWidth / (float)mHeight;
 
-	if (mCamera->m_pTR)
-		return mCamera->m_pTR->BeginTile();
-
 	if (mCamera->IsOrtho())
 	{
 		float OrthoHeight = mCamera->GetOrthoHeight() / 2.0f;
@@ -304,10 +310,63 @@ lcMatrix44 View::GetProjectionMatrix() const
 		return lcMatrix44Perspective(mCamera->m_fovy, AspectRatio, mCamera->m_zNear, mCamera->m_zFar);
 }
 
+lcMatrix44 View::GetTileProjectionMatrix(int CurrentRow, int CurrentColumn, int CurrentTileWidth, int CurrentTileHeight) const
+{
+	int ImageWidth = mRenderImage.width();
+	int ImageHeight = mRenderImage.height();
+
+	double ImageLeft, ImageRight, ImageBottom, ImageTop, Near, Far;
+	double AspectRatio = (double)ImageWidth / (double)ImageHeight;
+
+	if (mCamera->IsOrtho())
+	{
+		float OrthoHeight = mCamera->GetOrthoHeight() / 2.0f;
+		float OrthoWidth = OrthoHeight * AspectRatio;
+
+		ImageLeft = -OrthoWidth;
+		ImageRight = OrthoWidth;
+		ImageBottom = -OrthoHeight;
+		ImageTop = OrthoHeight;
+		Near = mCamera->m_zNear;
+		Far = mCamera->m_zFar * 4;
+	}
+	else
+	{
+		double xmin, xmax, ymin, ymax;
+		ymax = mCamera->m_zNear * tan(mCamera->m_fovy * 3.14159265 / 360.0);
+		ymin = -ymax;
+		xmin = ymin * AspectRatio;
+		xmax = ymax * AspectRatio;
+
+		ImageLeft = xmin;
+		ImageRight = xmax;
+		ImageBottom = ymin;
+		ImageTop = ymax;
+		Near = mCamera->m_zNear;
+		Far = mCamera->m_zFar;
+	}
+
+	double Left = ImageLeft + (ImageRight - ImageLeft) * (CurrentColumn * mWidth) / ImageWidth;
+	double Right = Left + (ImageRight - ImageLeft) * CurrentTileWidth / ImageWidth;
+	double Bottom = ImageBottom + (ImageTop - ImageBottom) * (CurrentRow * mHeight) / ImageHeight;
+	double Top = Bottom + (ImageTop - ImageBottom) * CurrentTileHeight / ImageHeight;
+
+	if (mCamera->IsOrtho())
+		return lcMatrix44Ortho(Left, Right, Bottom, Top, Near, Far);
+	else
+		return lcMatrix44Frustum(Left, Right, Bottom, Top, Near, Far);
+}
+
 LC_CURSOR_TYPE View::GetCursor() const
 {
-	if (mTrackTool == LC_TRACKTOOL_SELECT && (mInputState.Modifiers & Qt::ControlModifier))
-		return LC_CURSOR_SELECT_GROUP;
+	if (mTrackTool == LC_TRACKTOOL_SELECT)
+	{
+		if (mInputState.Modifiers & Qt::ControlModifier)
+			return LC_CURSOR_SELECT_ADD;
+
+		if (mInputState.Modifiers & Qt::ShiftModifier)
+			return LC_CURSOR_SELECT_REMOVE;
+	}
 
 	const LC_CURSOR_TYPE CursorFromTrackTool[] =
 	{
@@ -370,8 +429,11 @@ void View::ShowContextMenu() const
 
 	Popup->addSeparator();
 
-	Popup->addMenu(gMainWindow->GetCameraMenu());
+	Popup->addMenu(gMainWindow->GetToolsMenu());
 	Popup->addMenu(gMainWindow->GetViewpointMenu());
+	Popup->addMenu(gMainWindow->GetCameraMenu());
+	Popup->addMenu(gMainWindow->GetProjectionMenu());
+	Popup->addMenu(gMainWindow->GetShadingMenu());
 
 	Popup->addSeparator();
 
@@ -431,15 +493,19 @@ lcVector3 View::GetMoveDirection(const lcVector3& Direction) const
 	return axis;
 }
 
-lcMatrix44 View::GetPieceInsertPosition() const
+lcMatrix44 View::GetPieceInsertPosition(bool IgnoreSelected, PieceInfo* Info) const
 {
-	PieceInfo* CurPiece = gMainWindow->GetCurrentPieceInfo();
-	lcPiece* HitPiece = (lcPiece*)FindObjectUnderPointer(true).Object;
+	lcPiece* HitPiece = (lcPiece*)FindObjectUnderPointer(true, IgnoreSelected).Object;
 
 	if (HitPiece)
 	{
-		lcVector3 Position(0, 0, HitPiece->GetBoundingBox().Max.z - CurPiece->GetBoundingBox().Min.z);
-		Position = mModel->SnapPosition(lcMul31(Position, HitPiece->mModelWorld));
+		lcVector3 Position(0, 0, HitPiece->GetBoundingBox().Max.z - Info->GetBoundingBox().Min.z);
+
+		if (gMainWindow->GetRelativeTransform())
+			Position = lcMul31(mModel->SnapPosition(Position), HitPiece->mModelWorld);
+		else
+			Position = mModel->SnapPosition(lcMul31(Position, HitPiece->mModelWorld));
+
 		lcMatrix44 WorldMatrix = HitPiece->mModelWorld;
 		WorldMatrix.SetTranslation(Position);
 
@@ -451,7 +517,7 @@ lcMatrix44 View::GetPieceInsertPosition() const
 
 	lcVector3 Intersection;
 
-	const lcBoundingBox& BoundingBox = CurPiece->GetBoundingBox();
+	const lcBoundingBox& BoundingBox = Info->GetBoundingBox();
 	if (lcLinePlaneIntersection(&Intersection, ClickPoints[0], ClickPoints[1], lcVector4(0, 0, 1, BoundingBox.Min.z)))
 	{
 		Intersection = mModel->SnapPosition(Intersection);
@@ -475,7 +541,7 @@ void View::GetRayUnderPointer(lcVector3& Start, lcVector3& End) const
 	End = StartEnd[1];
 }
 
-lcObjectSection View::FindObjectUnderPointer(bool PiecesOnly) const
+lcObjectSection View::FindObjectUnderPointer(bool PiecesOnly, bool IgnoreSelected) const
 {
 	lcVector3 StartEnd[2] =
 	{
@@ -488,6 +554,7 @@ lcObjectSection View::FindObjectUnderPointer(bool PiecesOnly) const
 	lcObjectRayTest ObjectRayTest;
 
 	ObjectRayTest.PiecesOnly = PiecesOnly;
+	ObjectRayTest.IgnoreSelected = IgnoreSelected;
 	ObjectRayTest.ViewCamera = mCamera;
 	ObjectRayTest.Start = StartEnd[0];
 	ObjectRayTest.End = StartEnd[1];
@@ -560,8 +627,38 @@ lcArray<lcObject*> View::FindObjectsInBox(float x1, float y1, float x2, float y2
 	return ObjectBoxTest.Objects;
 }
 
+bool View::BeginRenderToImage(int Width, int Height)
+{
+	GLint MaxTexture;
+	glGetIntegerv(GL_MAX_TEXTURE_SIZE, &MaxTexture);
+
+	MaxTexture = qMin(MaxTexture, 2048);
+	MaxTexture /= QGLFormat::defaultFormat().samples();
+
+	int TileWidth = qMin(Width, MaxTexture);
+	int TileHeight = qMin(Height, MaxTexture);
+
+	mWidth = TileWidth;
+	mHeight = TileHeight;
+	mRenderImage = QImage(Width, Height, QImage::Format_ARGB32);
+
+	mRenderFramebuffer = mContext->CreateRenderFramebuffer(TileWidth, TileHeight);
+	mContext->BindFramebuffer(mRenderFramebuffer.first);
+	return mRenderFramebuffer.first.IsValid();
+}
+
+void View::EndRenderToImage()
+{
+	mRenderImage = QImage();
+	mContext->DestroyRenderFramebuffer(mRenderFramebuffer);
+	mContext->ClearFramebuffer();
+}
+
 void View::OnDraw()
 {
+	if (!mModel)
+		return;
+
 	bool DrawInterface = mWidget != nullptr;
 
 	mModel->GetScene(mScene, mCamera, DrawInterface, mHighlight);
@@ -571,21 +668,91 @@ void View::OnDraw()
 		PieceInfo* Info = gMainWindow->GetCurrentPieceInfo();
 
 		if (Info)
-			Info->AddRenderMeshes(mScene, GetPieceInsertPosition(), gMainWindow->mColorIndex, true, true, false);
+			Info->AddRenderMeshes(mScene, GetPieceInsertPosition(false, gMainWindow->GetCurrentPieceInfo()), gMainWindow->mColorIndex, true, true, false);
 	}
 
-	mContext->SetDefaultState();
-	mContext->SetViewport(0, 0, mWidth, mHeight);
+	int TotalTileRows = 1;
+	int TotalTileColumns = 1;
 
-	mModel->DrawBackground(this);
+	if (!mRenderImage.isNull())
+	{
+		int ImageWidth = mRenderImage.width();
+		int ImageHeight = mRenderImage.height();
+
+		if (ImageWidth > mWidth || ImageHeight > mHeight)
+		{
+			TotalTileColumns = (mWidth + ImageWidth - 1) / mWidth;
+			TotalTileRows = (mHeight + ImageHeight - 1) / mHeight;
+		}
+	}
 
 	const lcPreferences& Preferences = lcGetPreferences();
 
-	mContext->SetProjectionMatrix(GetProjectionMatrix());
+	for (int CurrentTileRow = 0; CurrentTileRow < TotalTileRows; CurrentTileRow++)
+	{
+		for (int CurrentTileColumn = 0; CurrentTileColumn < TotalTileColumns; CurrentTileColumn++)
+		{
+			mContext->SetDefaultState();
+			mContext->SetViewport(0, 0, mWidth, mHeight);
 
-	mContext->SetLineWidth(Preferences.mLineWidth);
+			mModel->DrawBackground(this);
 
-	mScene.Draw(mContext);
+			int CurrentTileWidth, CurrentTileHeight;
+
+			if (!mRenderImage.isNull() && (TotalTileRows > 1 || TotalTileColumns > 1))
+			{
+				if (CurrentTileRow < TotalTileRows - 1)
+					CurrentTileHeight = mHeight;
+				else
+					CurrentTileHeight = mRenderImage.height() - (TotalTileRows - 1) * (mHeight);
+
+				if (CurrentTileColumn < TotalTileColumns - 1)
+					CurrentTileWidth = mWidth;
+				else
+					CurrentTileWidth = mRenderImage.width() - (TotalTileColumns - 1) * (mWidth);
+
+				mContext->SetViewport(0, 0, CurrentTileWidth, CurrentTileHeight);
+				mContext->SetProjectionMatrix(GetTileProjectionMatrix(CurrentTileRow, CurrentTileColumn, CurrentTileWidth, CurrentTileHeight));
+			}
+			else
+			{
+				CurrentTileWidth = mWidth;
+				CurrentTileHeight = mHeight;
+
+				mContext->SetProjectionMatrix(GetProjectionMatrix());
+			}
+
+			mContext->SetLineWidth(Preferences.mLineWidth);
+
+			mScene.Draw(mContext);
+
+			if (!mRenderImage.isNull())
+			{
+				quint8* Buffer = (quint8*)malloc(mWidth * mHeight * 4);
+				uchar* ImageBuffer = mRenderImage.bits();
+
+				mContext->GetRenderFramebufferImage(mRenderFramebuffer, Buffer);
+
+				quint32 TileY = 0, SrcY = 0;
+				if (CurrentTileRow != TotalTileRows - 1)
+					TileY = (TotalTileRows - CurrentTileRow - 1) * mHeight - ((mHeight - mRenderImage.height() % mHeight) % mHeight);
+				else if (TotalTileRows > 1)
+					SrcY = (mHeight - mRenderImage.height() % mHeight) % mHeight;
+
+				quint32 TileStart = ((CurrentTileColumn * mWidth) + (TileY * mRenderImage.width())) * 4;
+
+				for (int y = 0; y < CurrentTileHeight; y++)
+				{
+					quint8* src = Buffer + (SrcY + y) * mWidth * 4;
+					quint8* dst = ImageBuffer + TileStart + y * mRenderImage.width() * 4;
+
+					memcpy(dst, src, CurrentTileWidth * 4);
+				}
+
+				free(Buffer);
+			}
+		}
+	}
 
 	if (DrawInterface)
 	{
@@ -642,7 +809,7 @@ void View::DrawSelectMoveOverlay()
 	mContext->SetVertexFormatPosition(3);
 
 	lcObject* Focus = mModel->GetFocusObject();
-	lcuint32 AllowedTransforms = Focus ? Focus->GetAllowedTransforms() : LC_OBJECT_TRANSFORM_MOVE_X | LC_OBJECT_TRANSFORM_MOVE_Y | LC_OBJECT_TRANSFORM_MOVE_Z | LC_OBJECT_TRANSFORM_ROTATE_X | LC_OBJECT_TRANSFORM_ROTATE_Y | LC_OBJECT_TRANSFORM_ROTATE_Z;
+	quint32 AllowedTransforms = Focus ? Focus->GetAllowedTransforms() : LC_OBJECT_TRANSFORM_MOVE_X | LC_OBJECT_TRANSFORM_MOVE_Y | LC_OBJECT_TRANSFORM_MOVE_Z | LC_OBJECT_TRANSFORM_ROTATE_X | LC_OBJECT_TRANSFORM_ROTATE_Y | LC_OBJECT_TRANSFORM_ROTATE_Z;
 
 	if (mTrackButton == LC_TRACKBUTTON_NONE || (mTrackTool >= LC_TRACKTOOL_MOVE_X && mTrackTool <= LC_TRACKTOOL_MOVE_XYZ))
 	{
@@ -741,7 +908,7 @@ void View::DrawSelectMoveOverlay()
 	if (Focus && Focus->IsPiece())
 	{
 		lcPiece* Piece = (lcPiece*)Focus;
-		lcuint32 Section = Piece->GetFocusSection();
+		quint32 Section = Piece->GetFocusSection();
 
 		if (Section >= LC_PIECE_SECTION_CONTROL_POINT_1 && Section <= LC_PIECE_SECTION_CONTROL_POINT_8 && Piece->mPieceInfo->GetSynthInfo() && Piece->mPieceInfo->GetSynthInfo()->IsCurve())
 		{
@@ -1080,7 +1247,7 @@ void View::DrawRotateOverlay()
 		mContext->SetWorldMatrix(lcMatrix44Identity());
 		mContext->SetViewMatrix(lcMatrix44Translation(lcVector3(0.375, 0.375, 0.0)));
 		mContext->SetProjectionMatrix(lcMatrix44Ortho(0.0f, mWidth, 0.0f, mHeight, -1.0f, 1.0f));
-		mContext->BindTexture(gTexFont.GetTexture());
+		mContext->BindTexture2D(gTexFont.GetTexture());
 		glEnable(GL_BLEND);
 
 		char buf[32];
@@ -1266,7 +1433,7 @@ void View::DrawGrid()
 			lcVector3 Points[8];
 			lcGetBoxCorners(CurPiece->GetBoundingBox(), Points);
 
-			lcMatrix44 WorldMatrix = GetPieceInsertPosition();
+			lcMatrix44 WorldMatrix = GetPieceInsertPosition(false, CurPiece);
 
 			for (int i = 0; i < 8; i++)
 			{
@@ -1394,7 +1561,7 @@ void View::DrawGrid()
 
 	if (Preferences.mDrawGridStuds)
 	{
-		mContext->BindTexture(gGridTexture->mTexture);
+		mContext->BindTexture2D(gGridTexture->mTexture);
 		glEnable(GL_BLEND);
 
 		mContext->SetMaterial(LC_MATERIAL_UNLIT_TEXTURE_MODULATE);
@@ -1469,7 +1636,7 @@ void View::DrawAxes()
 
 	mContext->SetMaterial(LC_MATERIAL_UNLIT_TEXTURE_MODULATE);
 	mContext->SetViewMatrix(TranslationMatrix);
-	mContext->BindTexture(gTexFont.GetTexture());
+	mContext->BindTexture2D(gTexFont.GetTexture());
 	glEnable(GL_BLEND);
 
 	float TextBuffer[6 * 5 * 3];
@@ -1515,7 +1682,7 @@ void View::DrawViewport()
 	{
 		mContext->SetMaterial(LC_MATERIAL_UNLIT_TEXTURE_MODULATE);
 		mContext->SetColor(0.0f, 0.0f, 0.0f, 1.0f);
-		mContext->BindTexture(gTexFont.GetTexture());
+		mContext->BindTexture2D(gTexFont.GetTexture());
 
 		glEnable(GL_BLEND);
 
@@ -1627,7 +1794,7 @@ void View::BeginPieceDrag()
 void View::EndPieceDrag(bool Accept)
 {
 	if (Accept)
-		mModel->InsertPieceToolClicked(GetPieceInsertPosition());
+		mModel->InsertPieceToolClicked(GetPieceInsertPosition(false, gMainWindow->GetCurrentPieceInfo()));
 
 	mDragState = LC_DRAGSTATE_NONE;
 	UpdateTrackTool();
@@ -1656,6 +1823,11 @@ void View::ZoomExtents()
 	mModel->ZoomExtents(mCamera, (float)mWidth / (float)mHeight);
 }
 
+void View::MoveCamera(const lcVector3& Direction)
+{
+	mModel->MoveCamera(mCamera, Direction);
+}
+
 void View::UpdateTrackTool()
 {
 	lcTool CurrentTool = gMainWindow->GetTool();
@@ -1694,6 +1866,7 @@ void View::UpdateTrackTool()
 			const float OverlayScaleRadius = 0.125f;
 
 			NewTrackTool = (CurrentTool == LC_TOOL_MOVE) ? LC_TRACKTOOL_MOVE_XYZ : LC_TRACKTOOL_SELECT;
+			mMouseDownPiece = nullptr;
 
 			lcVector3 OverlayCenter;
 			lcMatrix33 RelativeRotation;
@@ -1722,13 +1895,13 @@ void View::UpdateTrackTool()
 			if (Focus && Focus->IsPiece())
 			{
 				lcPiece* Piece = (lcPiece*)Focus;
-				lcuint32 Section = Piece->GetFocusSection();
+				quint32 Section = Piece->GetFocusSection();
 
 				if (Section >= LC_PIECE_SECTION_CONTROL_POINT_1 && Section <= LC_PIECE_SECTION_CONTROL_POINT_8)
 					ControlPointIndex = Section - LC_PIECE_SECTION_CONTROL_POINT_1;
 			}
 
-			lcuint32 AllowedTransforms = Focus ? Focus->GetAllowedTransforms() : LC_OBJECT_TRANSFORM_MOVE_X | LC_OBJECT_TRANSFORM_MOVE_Y | LC_OBJECT_TRANSFORM_MOVE_Z | LC_OBJECT_TRANSFORM_ROTATE_X | LC_OBJECT_TRANSFORM_ROTATE_Y | LC_OBJECT_TRANSFORM_ROTATE_Z;
+			quint32 AllowedTransforms = Focus ? Focus->GetAllowedTransforms() : LC_OBJECT_TRANSFORM_MOVE_X | LC_OBJECT_TRANSFORM_MOVE_Y | LC_OBJECT_TRANSFORM_MOVE_Z | LC_OBJECT_TRANSFORM_ROTATE_X | LC_OBJECT_TRANSFORM_ROTATE_Y | LC_OBJECT_TRANSFORM_ROTATE_Z;
 
 			for (int AxisIndex = 0; AxisIndex < 3; AxisIndex++)
 			{
@@ -1841,6 +2014,20 @@ void View::UpdateTrackTool()
 				}
 			}
 
+			if (CurrentTool == LC_TOOL_SELECT && NewTrackTool == LC_TRACKTOOL_SELECT && mInputState.Modifiers == Qt::NoModifier)
+			{
+				lcObjectSection ObjectSection = FindObjectUnderPointer(false, false);
+				lcObject* Object = ObjectSection.Object;
+
+				if (Object && Object->IsPiece() && ObjectSection.Section == LC_PIECE_SECTION_POSITION && Object->IsSelected())
+				{
+					lcPiece* Piece = (lcPiece*)Object;
+					mMouseDownPosition = Piece->mModelWorld.GetTranslation();
+					mMouseDownPiece = Piece->mPieceInfo;
+					NewTrackTool = LC_TRACKTOOL_MOVE_XYZ;
+				}
+			}
+
 			Redraw = true;
 		}
 		break;
@@ -2074,7 +2261,7 @@ void View::UpdateTrackTool()
 	}
 }
 
-bool View::IsTrackToolAllowed(lcTrackTool TrackTool, lcuint32 AllowedTransforms) const
+bool View::IsTrackToolAllowed(lcTrackTool TrackTool, quint32 AllowedTransforms) const
 {
 	switch (TrackTool)
 	{
@@ -2234,9 +2421,11 @@ void View::StopTracking(bool Accept)
 			lcArray<lcObject*> Objects = FindObjectsInBox(mMouseDownX, mMouseDownY, mInputState.x, mInputState.y);
 
 			if (mInputState.Modifiers & Qt::ControlModifier)
-				mModel->AddToSelection(Objects);
+				mModel->AddToSelection(Objects, true, true);
+			else if (mInputState.Modifiers & Qt::ShiftModifier)
+				mModel->RemoveFromSelection(Objects);
 			else
-				mModel->SetSelectionAndFocus(Objects, nullptr, 0);
+				mModel->SetSelectionAndFocus(Objects, nullptr, 0, true);
 		}
 		break;
 
@@ -2318,7 +2507,7 @@ void View::OnButtonDown(lcTrackButton TrackButton)
 			if (!CurPiece)
 				break;
 
-			mModel->InsertPieceToolClicked(GetPieceInsertPosition());
+			mModel->InsertPieceToolClicked(GetPieceInsertPosition(false, gMainWindow->GetCurrentPieceInfo()));
 
 			if ((mInputState.Modifiers & Qt::ControlModifier) == 0)
 				gMainWindow->SetTool(LC_TOOL_SELECT);
@@ -2345,12 +2534,14 @@ void View::OnButtonDown(lcTrackButton TrackButton)
 		
 	case LC_TRACKTOOL_SELECT:
 		{
-			lcObjectSection ObjectSection = FindObjectUnderPointer(false);
+			lcObjectSection ObjectSection = FindObjectUnderPointer(false, false);
 
 			if (mInputState.Modifiers & Qt::ControlModifier)
 				mModel->FocusOrDeselectObject(ObjectSection);
+			else if (mInputState.Modifiers & Qt::ShiftModifier)
+				mModel->RemoveFromSelection(ObjectSection);
 			else
-				mModel->ClearSelectionAndSetFocus(ObjectSection);
+				mModel->ClearSelectionAndSetFocus(ObjectSection, true);
 
 			StartTracking(TrackButton);
 		}
@@ -2383,11 +2574,11 @@ void View::OnButtonDown(lcTrackButton TrackButton)
 		break;
 
 	case LC_TRACKTOOL_ERASER:
-		mModel->EraserToolClicked(FindObjectUnderPointer(false).Object);
+		mModel->EraserToolClicked(FindObjectUnderPointer(false, false).Object);
 		break;
 
 	case LC_TRACKTOOL_PAINT:
-		mModel->PaintToolClicked(FindObjectUnderPointer(true).Object);
+		mModel->PaintToolClicked(FindObjectUnderPointer(true, false).Object);
 		break;
 
 	case LC_TRACKTOOL_ZOOM:
@@ -2432,12 +2623,14 @@ void View::OnLeftButtonDoubleClick()
 {
 	gMainWindow->SetActiveView(this);
 
-	lcObjectSection ObjectSection = FindObjectUnderPointer(false);
+	lcObjectSection ObjectSection = FindObjectUnderPointer(false, false);
 
 	if (mInputState.Modifiers & Qt::ControlModifier)
 		mModel->FocusOrDeselectObject(ObjectSection);
+	else if (mInputState.Modifiers & Qt::ShiftModifier)
+		mModel->RemoveFromSelection(ObjectSection);
 	else
-		mModel->ClearSelectionAndSetFocus(ObjectSection);
+		mModel->ClearSelectionAndSetFocus(ObjectSection, true);
 }
 
 void View::OnMiddleButtonDown()
@@ -2510,6 +2703,9 @@ void View::OnForwardButtonUp()
 
 void View::OnMouseMove()
 {
+	if (!mModel)
+		return;
+
 	if (mTrackButton == LC_TRACKBUTTON_NONE)
 	{
 		UpdateTrackTool();
@@ -2620,6 +2816,12 @@ void View::OnMouseMove()
 					}
 				}
 			}
+			else if (mTrackTool == LC_TRACKTOOL_MOVE_XYZ && mMouseDownPiece)
+			{
+				lcMatrix44 NewPosition = GetPieceInsertPosition(true, mMouseDownPiece);
+				lcVector3 Distance = NewPosition.GetTranslation() - mMouseDownPosition;
+				mModel->UpdateMoveTool(Distance, mTrackButton != LC_TRACKBUTTON_LEFT);
+			}
 			else if (mTrackTool == LC_TRACKTOOL_SCALE_PLUS || mTrackTool == LC_TRACKTOOL_SCALE_MINUS)
 			{
 				lcVector3 Direction;
@@ -2637,7 +2839,7 @@ void View::OnMouseMove()
 				if (Focus && Focus->IsPiece())
 				{
 					lcPiece* Piece = (lcPiece*)Focus;
-					lcuint32 Section = Piece->GetFocusSection();
+					quint32 Section = Piece->GetFocusSection();
 
 					if (Section >= LC_PIECE_SECTION_CONTROL_POINT_1 && Section <= LC_PIECE_SECTION_CONTROL_POINT_8)
 					{
