@@ -2,6 +2,7 @@
 #include "lc_qmodellistdialog.h"
 #include "ui_lc_qmodellistdialog.h"
 #include "project.h"
+#include "lc_profile.h"
 
 lcQModelListDialog::lcQModelListDialog(QWidget* Parent, QList<QPair<QString, lcModel*>>& Models)
 	: QDialog(Parent), mModels(Models), ui(new Ui::lcQModelListDialog)
@@ -14,7 +15,8 @@ lcQModelListDialog::lcQModelListDialog(QWidget* Parent, QList<QPair<QString, lcM
 		Item->setData(Qt::UserRole, qVariantFromValue<uintptr_t>((uintptr_t)it->second));
 		ui->ModelList->addItem(Item);
 	}
-	ui->ModelList->setCurrentRow(0);
+	ui->ModelList->setCurrentRow(lcGetActiveProject()->GetActiveModelIndex());
+	UpdateButtons();
 }
 
 lcQModelListDialog::~lcQModelListDialog()
@@ -22,6 +24,16 @@ lcQModelListDialog::~lcQModelListDialog()
 	delete ui;
 }
 
+void lcQModelListDialog::UpdateButtons()
+{
+	int CurrentModel = ui->ModelList->currentRow();
+	int NumModels = ui->ModelList->count();
+
+	ui->DeleteModel->setEnabled(NumModels > 1);
+	ui->MoveUp->setEnabled(NumModels > 1 && CurrentModel > 0);
+	ui->MoveDown->setEnabled(NumModels > 1 && CurrentModel < NumModels - 1);
+}
+
 void lcQModelListDialog::accept()
 {
 	mModels.clear();
@@ -41,24 +53,12 @@ void lcQModelListDialog::accept()
 
 void lcQModelListDialog::on_NewModel_clicked()
 {
-	const QString Prefix = tr("Model #");
-	int Max = 0;
+	QStringList ModelNames;
 
 	for (int ItemIdx = 0; ItemIdx < ui->ModelList->count(); ItemIdx++)
-	{
-		const QString& Name = ui->ModelList->item(ItemIdx)->text();
+		ModelNames.append(ui->ModelList->item(ItemIdx)->text());
 
-		if (Name.startsWith(Prefix))
-		{
-			QString NumberString = Name.mid(Prefix.length());
-			QTextStream Stream(&NumberString);
-			int Number;
-			Stream >> Number;
-			Max = qMax(Max, Number);
-		}
-	}
-
-	QString Name = Prefix + QString::number(Max + 1) + ".ldr";
+	QString Name = lcGetActiveProject()->GetNewModelName(this, tr("New Submodel"), QString(), ModelNames);
 
 	if (Name.isEmpty())
 		return;
@@ -66,13 +66,14 @@ void lcQModelListDialog::on_NewModel_clicked()
 	QListWidgetItem* Item = new QListWidgetItem(Name);
 	Item->setData(Qt::UserRole, qVariantFromValue<uintptr_t>(0));
 	ui->ModelList->addItem(Item);
+	UpdateButtons();
 }
 
 void lcQModelListDialog::on_DeleteModel_clicked()
 {
 	if (ui->ModelList->count() == 1)
 	{
-		QMessageBox::information(this, tr("Error"), tr("The project must have at least 1 model."));
+		QMessageBox::information(this, tr("Error"), tr("The model cannot be empty."));
 		return;
 	}
 
@@ -81,11 +82,12 @@ void lcQModelListDialog::on_DeleteModel_clicked()
 	if (SelectedItems.isEmpty())
 		return;
 
-	QString Prompt = tr("Are you sure you want to delete the model '%1'?").arg(SelectedItems[0]->text());
-	if (QMessageBox::question(this, tr("Delete Model"), Prompt, QMessageBox::Yes | QMessageBox::No) != QMessageBox::Yes)
+	QString Prompt = tr("Are you sure you want to delete the submodel '%1'?").arg(SelectedItems[0]->text());
+	if (QMessageBox::question(this, tr("Delete Submodel"), Prompt, QMessageBox::Yes | QMessageBox::No) != QMessageBox::Yes)
 		return;
 
 	delete SelectedItems[0];
+	UpdateButtons();
 }
 
 void lcQModelListDialog::on_RenameModel_clicked()
@@ -100,12 +102,39 @@ void lcQModelListDialog::on_RenameModel_clicked()
 	for (int ItemIdx = 0; ItemIdx < ui->ModelList->count(); ItemIdx++)
 		ModelNames.append(ui->ModelList->item(ItemIdx)->text());
 
-	QString Name = lcGetActiveProject()->GetNewModelName(this, tr("Rename Model"), SelectedItems[0]->text(), ModelNames);
+	QString Name = lcGetActiveProject()->GetNewModelName(this, tr("Rename Submodel"), SelectedItems[0]->text(), ModelNames);
 
 	if (!Name.isEmpty())
 		SelectedItems[0]->setText(Name);
 }
 
+void lcQModelListDialog::on_ExportModel_clicked()
+{
+	QListWidgetItem* CurrentItem = ui->ModelList->currentItem();
+
+	if (!CurrentItem)
+		return;
+
+	lcModel* Model = (lcModel*)CurrentItem->data(Qt::UserRole).value<uintptr_t>();
+
+	if (!Model)
+	{
+		QMessageBox::information(this, tr("LeoCAD"), tr("Nothing to export."));
+		return;
+	}
+
+	QString SaveFileName = QFileInfo(QDir(lcGetProfileString(LC_PROFILE_PROJECTS_PATH)), CurrentItem->text()).absoluteFilePath();
+
+	SaveFileName = QFileDialog::getSaveFileName(this, tr("Save Model"), SaveFileName, tr("Supported Files (*.ldr *.dat);;All Files (*.*)"));
+
+	if (SaveFileName.isEmpty())
+		return;
+
+	lcGetActiveProject()->ExportModel(SaveFileName, Model);
+
+	lcSetProfileString(LC_PROFILE_PROJECTS_PATH, QFileInfo(SaveFileName).absolutePath());
+}
+
 void lcQModelListDialog::on_MoveUp_clicked()
 {
 	QList<QListWidgetItem*>	SelectedItems = ui->ModelList->selectedItems();
@@ -122,6 +151,7 @@ void lcQModelListDialog::on_MoveUp_clicked()
 	ui->ModelList->takeItem(Row);
 	ui->ModelList->insertItem(Row - 1, Item);
 	ui->ModelList->setCurrentItem(Item);
+	UpdateButtons();
 }
 
 void lcQModelListDialog::on_MoveDown_clicked()
@@ -137,6 +167,7 @@ void lcQModelListDialog::on_MoveDown_clicked()
 	ui->ModelList->takeItem(Row);
 	ui->ModelList->insertItem(Row + 1, Item);
 	ui->ModelList->setCurrentItem(Item);
+	UpdateButtons();
 }
 
 void lcQModelListDialog::on_ModelList_itemDoubleClicked(QListWidgetItem* Item)
@@ -145,3 +176,10 @@ void lcQModelListDialog::on_ModelList_itemDoubleClicked(QListWidgetItem* Item)
 
 	accept();
 }
+
+void lcQModelListDialog::on_ModelList_currentRowChanged(int CurrentRow)
+{
+	Q_UNUSED(CurrentRow);
+
+	UpdateButtons();
+}
\ No newline at end of file
