@@ -435,7 +435,7 @@ QWidget *lcQPropertiesTree::createEditor(QWidget *parent, QTreeWidgetItem *item)
 	case PropertyInt:
 		{
 			QLineEdit *editor = new QLineEdit(parent);
-			lcuint32 value = item->data(0, PropertyValueRole).toUInt();
+			quint32 value = item->data(0, PropertyValueRole).toUInt();
 
 			editor->setValidator(new QIntValidator());
 			editor->setText(QString::number(value));
@@ -476,10 +476,22 @@ QWidget *lcQPropertiesTree::createEditor(QWidget *parent, QTreeWidgetItem *item)
 			editor->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
 			editor->setMinimumContentsLength(1);
 
-			lcPiecesLibrary* library = lcGetPiecesLibrary();
-			for (int partIdx = 0; partIdx < library->mPieces.GetSize(); partIdx++)
-				editor->addItem(library->mPieces[partIdx]->m_strDescription, qVariantFromValue((void*)library->mPieces[partIdx]));
-			editor->model()->sort(0);
+			lcPiecesLibrary* Library = lcGetPiecesLibrary();
+			std::vector<PieceInfo*> SortedPieces;
+			SortedPieces.reserve(Library->mPieces.size());
+
+			for (const auto PartIt : Library->mPieces)
+				SortedPieces.push_back(PartIt.second);
+
+			auto PieceCompare = [](PieceInfo* Info1, PieceInfo* Info2)
+			{
+				return strcmp(Info1->m_strDescription, Info2->m_strDescription) < 0;
+			};
+
+			std::sort(SortedPieces.begin(), SortedPieces.end(), PieceCompare);
+
+			for (PieceInfo* Info : SortedPieces)
+				editor->addItem(Info->m_strDescription, qVariantFromValue((void*)Info));
 
 			PieceInfo *info = (PieceInfo*)item->data(0, PropertyValueRole).value<void*>();
 			editor->setCurrentIndex(editor->findData(qVariantFromValue((void*)info)));
