@@ -2,9 +2,6 @@
 #include "lc_application.h"
 #include "lc_qupdatedialog.h"
 #include "lc_mainwindow.h"
-#include "project.h"
-#include "lc_colors.h"
-#include "lc_partselectionwidget.h"
 #include <QApplication>
 #include <locale.h>
 
@@ -130,76 +127,54 @@ static void lcRegisterShellFileTypes()
 
 int main(int argc, char *argv[])
 {
-	QApplication app(argc, argv);
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
-	app.setApplicationDisplayName("LeoCAD");
-#endif
-
-	QCoreApplication::setOrganizationDomain("leocad.org");
-	QCoreApplication::setOrganizationName("LeoCAD Software");
-	QCoreApplication::setApplicationName("LeoCAD");
-	QCoreApplication::setApplicationVersion(LC_VERSION_TEXT);
+	lcApplication Application(argc, argv);
 
 	QTranslator Translator;
 	Translator.load(QString("leocad_") + QLocale::system().name().section('_', 0, 0) + ".qm", ":/resources");
-	app.installTranslator(&Translator);
+	Application.installTranslator(&Translator);
 
 	qRegisterMetaTypeStreamOperators<QList<int> >("QList<int>");
 
-	g_App = new lcApplication();
-
-#if defined(Q_OS_WIN)
-	char libPath[LC_MAXPATH], *ptr;
-	strcpy(libPath, argv[0]);
-	ptr = strrchr(libPath,'\\');
-	if (ptr)
-		*(++ptr) = 0;
+	QList<QPair<QString, bool>> LibraryPaths;
 
+#ifdef Q_OS_WIN
 	lcRegisterShellFileTypes();
 	lcSehInit();
-#elif defined(Q_OS_MAC)
-	QDir bundlePath = QDir(QCoreApplication::applicationDirPath());
-	bundlePath.cdUp();
-	bundlePath.cdUp();
-	bundlePath = QDir::cleanPath(bundlePath.absolutePath() + "/Contents/Resources/");
-	QByteArray pathArray = bundlePath.absolutePath().toLocal8Bit();
-	const char* libPath = pathArray.data();
-#else
-	const char* libPath = LC_INSTALL_PREFIX "/share/leocad/";
+
+	LibraryPaths += qMakePair(QDir::cleanPath(QCoreApplication::applicationDirPath() + "/library.bin"), true);
+#endif
+
+#ifdef Q_OS_LINUX
+	LibraryPaths += qMakePair(QDir::cleanPath(QCoreApplication::applicationDirPath() + "/../share/leocad/library.bin"), true);
+#endif
+
+#ifdef Q_OS_MAC
+	LibraryPaths += qMakePair(QDir::cleanPath(QCoreApplication::applicationDirPath() + "/../../Contents/Resources/library.bin"), true);
 #endif
 
 #ifdef LC_LDRAW_LIBRARY_PATH
-	const char* LDrawPath = LC_LDRAW_LIBRARY_PATH;
-#else
-	const char* LDrawPath = nullptr;
+	LibraryPaths += qMakePair(QString::fromLatin1(LC_LDRAW_LIBRARY_PATH), false);
 #endif
 	
 	setlocale(LC_NUMERIC, "C");
 
 	bool ShowWindow;
-	if (!g_App->Initialize(argc, argv, libPath, LDrawPath, ShowWindow))
+	if (!Application.Initialize(LibraryPaths, ShowWindow))
 		return 1;
 
 	int ExecReturn = 0;
 
 	if (ShowWindow)
 	{
-		gMainWindow->SetColorIndex(lcGetColorIndex(4));
-		gMainWindow->GetPartSelectionWidget()->SetDefaultPart();
-		gMainWindow->UpdateRecentFiles();
-		gMainWindow->show();
-
 #if !LC_DISABLE_UPDATE_CHECK
 		lcDoInitialUpdateCheck();
 #endif
 
-		ExecReturn = app.exec();
+		ExecReturn = Application.exec();
 	}
 
 	delete gMainWindow;
 	gMainWindow = nullptr;
-	delete g_App;
-	g_App = nullptr;
 
 	return ExecReturn;
 }
